package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.26.2 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.26.2) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`/@`!````@"````````!``````````%BQ````
M`````````$``.``)`$``'``;``8````$````0`````````!``````````$``
M````````^`$```````#X`0````````@``````````P````0````X`@``````
M`#@"````````.`(````````<`````````!P``````````0`````````!````
M!0```````````````````````````````````."=````````X)T`````````
M`"````````$````&````8*L```````!@JR```````&"K(```````P`0`````
M``!(%0``````````(````````@````8```"(JP```````(BK(```````B*L@
M``````!``@```````$`"````````"``````````$````!````%0"````````
M5`(```````!4`@```````$0`````````1``````````$`````````%#E=&0$
M````^)8```````#XE@```````/B6````````[`````````#L``````````0`
M````````4>5T9`8`````````````````````````````````````````````
M````````````$`````````!2Y71D!````&"K````````8*L@``````!@JR``
M`````*`$````````H`0````````!`````````"]L:6(V-"]L9"UL:6YU>"UX
M.#8M-C0N<V\N,@`$````$`````$```!'3E4```````,````"``````````0`
M```4`````P```$=.50#Q)(IKXYQ[SP"'"6=$A=C$6M/\E!$```!$````!```
M``@````@'!``!4`$AB@"0`"0A@"`@BD`($D@!`FXHAA-N@0&"@````!$````
M2````$P```!-````5````%4```!7````6P```%P`````````7@```&$```!B
M````8P``````````````;L7?'^K3[P[.WD<M:W^:?"[%F[8@_^0.N(WQ#M5D
MU'S9<5@<XD?&`:Q+X\#RV],=NN.2?,+E/RSZH6Q@LP&+;VL)0]9FK\QFQ;F<
M0$)%U>S$B060B`=PTSGRBQP-%.*>VLWCGC-BV^T,.I<+5J2;EJ?=HVM_J9R;
MX:<""@J*$%>CX/M)````````````````````````````````$0$``!(`````
M````````````````````_`$``!(`````````````````````````<@(``!(`
M````````````````````````4`(``!(`````````````````````````$0``
M`"``````````````````````````>0(``!(`````````````````````````
M!0,``!(`````````````````````````M````!(`````````````````````
M````C@(``!(`````````````````````````@P$``!(`````````````````
M````````[0(``!(`````````````````````````Y0(``!(`````````````
M````````````A````!(`````````````````````````U`,``!(`````````
M````````````````#`$``!(`````````````````````````L0(``!(`````
M````````````````````HP(``!(`````````````````````````80(``!(`
M````````````````````````_@(``!(`````````````````````````&P,`
M`!(`````````````````````````9P$``!(`````````````````````````
M-0$``!(`````````````````````````P@```!(`````````````````````
M````L0$``!(`````````````````````````*0(``!(`````````````````
M````````6`(``!(`````````````````````````.0(``!(`````````````
M````````````G@$``!(`````````````````````````AP(``!(`````````
M````````````````]P$``!(`````````````````````````7P,``!(`````
M````````````````````6`,``!(`````````````````````````0P$``!(`
M````````````````````````#@,``!(`````````````````````````+0``
M`"``````````````````````````Q0(``!(`````````````````````````
M9````!(`````````````````````````%0(``!(`````````````````````
M````J@$``!(`````````````````````````DP```!(`````````````````
M````````GP```!(`````````````````````````7`$``!(`````````````
M````````````(@$``!(`````````````````````````5@```!(`````````
M````````````````%@$``!(`````````````````````````S`(``!(`````
M````````````````````DP$``!(`````````````````````````\````!(`
M````````````````````````?P(``!(`````````````````````````\`$`
M`!(`````````````````````````20,``!(`````````````````````````
M(@,``!(`````````````````````````=0$``!(`````````````````````
M````<P```!(`````````````````````````40,``!(`````````````````
M````````G`(``!(`````````````````````````U````!(`````````````
M````````````4P$``!(`````````````````````````V@(``!(`````````
M````````````````2P(``!(`````````````````````````#0(``!(`````
M````````````````````MP(``!(`````````````````````````/````"``
M````````````````````````E0(``!(`````````````````````````+`,`
M`"(`````````````````````````J@(``!(`````````````````````````
M.P,``!(`````````````````````````W0,``!(`#@"@5@```````'``````
M````JP,``!(`#P"45P```````````````````@0``!(`#@!01@```````%0,
M````````;`,``!(`#@!0'@```````"T"````````L0,``!(`#@"0/P``````
M``4`````````<`0``!(`#@"@/P```````!H"````````:@0``!(`"P!@&@``
M````````````````G00``!(`#@"P4@```````.T#````````D`,``!``&0`@
ML"``````````````````Z0,``!(`#@#`00```````"H`````````'`0``!$`
M$`"@5P````````0`````````O`$``!$`%0!PJR```````!,`````````G`,`
M`!``&0"HP"``````````````````:`0``!(`#@!`/@```````#``````````
M?00``!(`#@!P10```````-P`````````CP0``!(`#@#`1````````'0`````
M````#P0``!``&```L"``````````````````]@,``!(`#@#P00```````.P`
M````````<0,``!$`&0!(L"````````@`````````B0,``!``&``@L"``````
M````````````<@,``"$`&0!(L"````````@`````````400``!$`&``8L"``
M``````@`````````]P(``!$`&0!@L"````````@`````````H0,``!(`#@"0
M5P````````(`````````000``!(`#@`@5P```````&4`````````%00``!(`
M#@"`(````````"L`````````$00``"``&```L"```````````````````0$`
M`!$`&0`@L"````````0`````````<P,``"$`&0!(L"````````@`````````
MP@,``!(`#@!`10```````"0`````````*P0``!(`#@#`/@```````,$`````
M````XP```!$`&0!`L"````````$`````````6P0``!(`#@#@0@```````-L!
M`````````&QI8G!E<FPN<V\N-2XR-@!?251-7V1E<F5G:7-T97)434-L;VYE
M5&%B;&4`7U]G;6]N7W-T87)T7U\`7TE435]R96=I<W1E<E1-0VQO;F5486)L
M90!097)L7W-Y<U]T97)M`%!E<FQ?<WES7VEN:70S`%!E<FQ?871F;W)K7VQO
M8VL`<&5R;%]C;VYS=')U8W0`4&5R;%]G971?<W8`4&5R;%]C<F]A:U]N;V-O
M;G1E>'0`4&5R;%]A=E]S:&EF=`!097)L7W-V7S)P=E]F;&%G<P!097)L7W-V
M7W-E='!V;@!03%]D;U]U;F1U;7``4&5R;%]N97=84U]F;&%G<P!03%]T:')?
M:V5Y`'!E<FQ?9G)E90!097)L7VUG7W-E=`!097)L7V%T9F]R:U]U;FQO8VL`
M4&5R;%]S=E]S971P=@!097)L7V=V7V9E=&-H<'8`<&5R;%]R=6X`4&5R;%]N
M97=84P!P97)L7V1E<W1R=6-T`%!E<FQ?879?9F5T8V@`8F]O=%]$>6YA3&]A
M9&5R`'!E<FQ?<&%R<V4`4&5R;%]S869E<WES;6%L;&]C`'!E<FQ?86QL;V,`
M4$Q?;65M;W)Y7W=R87``;&EB9&PN<V\N,@!L:6)M+G-O+C8`;&EB<'1H<F5A
M9"YS;RXP`&]P96XV-`!R96%D`%]?97)R;F]?;&]C871I;VX`;'-E96LV-`!P
M=&AR96%D7V=E='-P96-I9FEC`&-L;W-E`&QI8F,N<V\N-@!?7W)E9VES=&5R
M7V%T9F]R:P!E>&ET`'-T<FYC;7``8VQO<V5D:7(`7U]S=&%C:U]C:&M?9F%I
M;`!U;FQI;FL`;6MD:7(`<F5A;&QO8P!M96UC:'(`9V5T<&ED`'-T<F1U<`!S
M=')T;VL`<W1R;&5N`'-T<G-T<@!R;61I<@!?7V9P<FEN=&9?8VAK`&UE;6-P
M>0!?7W-T<FYC<'E?8VAK`%]?;'AS=&%T-C0`;W!E;F1I<@!?7WAS=&%T-C0`
M<W1D97)R`&=E='5I9`!R96%D;&EN:P!?7VUE;6-P>5]C:&L`<W1R8VAR`')E
M861D:7(V-`!?7V-X85]F:6YA;&EZ90!?7W-P<FEN=&9?8VAK`&UE;6UO=F4`
M86-C97-S`'-T<F-M<`!?7VQI8F-?<W1A<G1?;6%I;@!?7V5N=FER;VX`;&EB
M8W)Y<'0N<V\N,0!?961A=&$`7U]B<W-?<W1A<G0`7V5N9`!?7VQI8F-?8W-U
M7V9I;FD`<&%R7V-U<G)E;G1?97AE8P!G971?=7-E<FYA;65?9G)O;5]G971P
M=W5I9`!P87)?8VQE86YU<`!P87)?8F%S96YA;64`<&%R7V1I<FYA;64`<&%R
M7VUK=&UP9&ER`%]?9&%T85]S=&%R=`!?24]?<W1D:6Y?=7-E9`!P87)?8W5R
M<F5N=%]E>&5C7W!R;V,`7U]L:6)C7V-S=5]I;FET`&UY7W!A<E]P;`!P87)?
M:6YI=%]E;G8`>'-?:6YI=`!P87)?9FEN9'!R;V<`<&%R7W-E='5P7VQI8G!A
M=&@`<&%R7V5N=E]C;&5A;@!84U]);G1E<FYA;'-?4$%27T)/3U0`1TQ)0D-?
M,BXR+C4`1TQ)0D-?,BXQ-`!'3$E"0U\R+C,N-`!'3$E"0U\R+C,N,@!'3$E"
M0U\R+C0````"``,``@`"`````@`"`````@````(``@````(````"``(`!``"
M``(````````````#``(`!0````(``P`"``(````&````!P````,``@``````
M```````````&```````"``,``@`"```````"``(```````(``@`#``8````"
M``(``@`&``$``0`!``$``0`!``$``0`!``$``0````$``0`!``$``0`!``(`
M`0`"``$``@`!``$``0`!`````@`!``$````!`````0`!`.`!```0````(```
M`'4::0D```,`LP0````````!``4`+P(``!``````````E)&6!@``!P"_!```
M$````'09:0D```8`R@0``!````!R&6D)```%`-8$```0````%&EI#0``!`#B
M!```$````'4::0D```(`LP0```````!@JR````````@`````````@"$`````
M``!HJR````````@`````````0"$````````(L"````````@`````````"+`@
M```````8L"````````@`````````P%H```````"XKR````````8````%````
M``````````#`KR````````8````*``````````````#(KR````````8````?
M``````````````#0KR````````8````C``````````````#8KR````````8`
M```K``````````````#@KR````````8````V``````````````#HKR``````
M``8````_``````````````#PKR````````8```!!``````````````!PJR``
M``````4```!/```````````````@L"````````4```!?``````````````!`
ML"````````4```!C``````````````!(L"````````4```!6````````````
M``!@L"````````4```!:``````````````#@K2````````<````!````````
M``````#HK2````````<````"``````````````#PK2````````<````#````
M``````````#XK2````````<````$````````````````KB````````<````&
M```````````````(KB````````<````'```````````````0KB````````<`
M```(```````````````8KB````````<````)```````````````@KB``````
M``<````+```````````````HKB````````<````,```````````````PKB``
M``````<````-```````````````XKB````````<````.``````````````!`
MKB````````<````/``````````````!(KB````````<````0````````````
M``!0KB````````<````1``````````````!8KB````````<````2````````
M``````!@KB````````<````3``````````````!HKB````````<````4````
M``````````!PKB````````<````5``````````````!XKB````````<````6
M``````````````"`KB````````<````7``````````````"(KB````````<`
M```8``````````````"0KB````````<````9``````````````"8KB``````
M``<````:``````````````"@KB````````<````;``````````````"HKB``
M``````<````<``````````````"PKB````````<````=``````````````"X
MKB````````<````>``````````````#`KB````````<````@````````````
M``#(KB````````<````A``````````````#0KB````````<````B````````
M``````#8KB````````<````D``````````````#@KB````````<````E````
M``````````#HKB````````<````F``````````````#PKB````````<````G
M``````````````#XKB````````<````H````````````````KR````````<`
M```I```````````````(KR````````<````J```````````````0KR``````
M``<````L```````````````8KR````````<````M```````````````@KR``
M``````<````N```````````````HKR````````<````O```````````````P
MKR````````<````P```````````````XKR````````<````Q````````````
M``!`KR````````<````R``````````````!(KR````````<````S````````
M``````!0KR````````<````T``````````````!8KR````````<````U````
M``````````!@KR````````<````W``````````````!HKR````````<````X
M``````````````!PKR````````<````Y``````````````!XKR````````<`
M```Z``````````````"`KR````````<````[``````````````"(KR``````
M``<````\``````````````"0KR````````<````]``````````````"8KR``
M``````<````^``````````````"@KR````````<```!```````````````"H
MKR````````<```!"``````````````"PKR````````<```!#````````````
M``!(@^P(2(L%994@`$B%P'0"_]!(@\0(PP```````````/\U2I,@`/\E3),@
M``\?0`#_)4J3(`!H`````.G@_____R5"DR``:`$```#IT/____\E.I,@`&@"
M````Z<#_____)3*3(`!H`P```.FP_____R4JDR``:`0```#IH/____\E(I,@
M`&@%````Z9#_____)1J3(`!H!@```.F`_____R42DR``:`<```#I</____\E
M"I,@`&@(````Z6#_____)0*3(`!H"0```.E0_____R7ZDB``:`H```#I0/__
M__\E\I(@`&@+````Z3#_____)>J2(`!H#````.D@_____R7BDB``:`T```#I
M$/____\EVI(@`&@.````Z0#_____)=*2(`!H#P```.GP_O___R7*DB``:!``
M``#IX/[___\EPI(@`&@1````Z=#^____);J2(`!H$@```.G`_O___R6RDB``
M:!,```#IL/[___\EJI(@`&@4````Z:#^____):*2(`!H%0```.F0_O___R6:
MDB``:!8```#I@/[___\EDI(@`&@7````Z7#^____)8J2(`!H&````.E@_O__
M_R6"DB``:!D```#I4/[___\E>I(@`&@:````Z4#^____)7*2(`!H&P```.DP
M_O___R5JDB``:!P```#I(/[___\E8I(@`&@=````Z1#^____)5J2(`!H'@``
M`.D`_O___R52DB``:!\```#I\/W___\E2I(@`&@@````Z>#]____)4*2(`!H
M(0```.G0_?___R4ZDB``:"(```#IP/W___\E,I(@`&@C````Z;#]____)2J2
M(`!H)````.F@_?___R4BDB``:"4```#ID/W___\E&I(@`&@F````Z8#]____
M)1*2(`!H)P```.EP_?___R4*DB``:"@```#I8/W___\E`I(@`&@I````Z5#]
M____)?J1(`!H*@```.E`_?___R7RD2``:"L```#I,/W___\EZI$@`&@L````
MZ2#]____)>*1(`!H+0```.D0_?___R7:D2``:"X```#I`/W___\ETI$@`&@O
M````Z?#\____)<J1(`!H,````.G@_/___R7"D2``:#$```#IT/S___\ENI$@
M`&@R````Z<#\____);*1(`!H,P```.FP_/___R6JD2``:#0```#IH/S___\E
MHI$@`&@U````Z9#\____)9J1(`!H-@```.F`_/___R62D2``:#<```#I</S_
M__\EBI$@`&@X````Z6#\____)8*1(`!H.0```.E0_/___R5ZD2``:#H```#I
M0/S___\EJI$@`&:0``````````!54TB#[#B)?"0<2(ET)!!(C7PD'$B)5"0(
M2(UT)!!(C50D"&1(BP0E*````$B)1"0H,<#H"/[__TB+-4F1(`!(BSU*D2``
M2(GRZ'(X``"`/9N1(```=2_H-/W__TB%P$B)!>JA(``/A+<!``!(B<?H;/S_
M_XL]5I$@`.C1_?__QH#1"````(L]1)$@`.B__?__@(BJ!````HL],I$@`.BM
M_?__@(BJ!````8M$)!R->`5(N/________\?2&/_2#G'#X<B`0``2,'G`TB-
M'5(Z``#H^?S__TB+?"002(D%5:$@`,<%4Z$@``0```!(BQ=(B5@(2(T=+#H`
M`$B)6!A(B1!(BQ6_D"``2(E0$(M4)!R#^@%$C4H$?BU$C4H$2(/'"+X%````
M9@\?A```````3(L'2&/.@\8!2(/'"$$Y\4R)1,CX=>E(BST"H2``36/)2(TU
MR!X``(/"`T4QP$K'1,CX`````$B)P>AA_?__A<")PW1D2(L]U*`@`$B-;"0D
MZ-K[__](C3UG.```,<!(B>[HN1<``$B%P'0J2(L]K:`@`.A8^___Z//\__^)
MV$B+7"0H9$@S'"4H````=5](@\0X6UW#2(L]>Z`@`$B%_W0LZ'DV``#KPTB+
M/7"@(`#HB_W__XG#ZXQ(C34PBR``2(T]KS<``#'`Z(+\__](C3VD-P``2(GN
MZ$,7``!(A<!(B<=(B04NH"``=(#KM.@-^___OP$```#H8_W__P\?`#'M28G1
M7DB)XDB#Y/!05$R-!?HV``!(C0V#-@``2(T]K/W___\5'H\@`/0/'T0``$B-
M/6F/(`!52(T%88\@`$@Y^$B)Y7092(L%ZHX@`$B%P'0-7?_@9BX/'X0`````
M`%W##Q]``&8N#Q^$``````!(C3TICR``2(TU(H\@`%5(*?Y(B>5(P?X#2(GP
M2,'H/T@!QDC1_G082(L%R8X@`$B%P'0,7?_@9@\?A```````7<,/'T``9BX/
M'X0``````(`](8\@``!U+TB#/9^.(```54B)Y70,2(L]JHX@`.C=_/__Z$C_
M___&!?F.(``!7<,/'X``````\\-F#Q]$``!52(GE7>EF____9@\?1```05=!
M5DR-3SA!54%413'`55-(@>R8`@``9$B+!"4H````2(F$)(@"```QP$B)X6:0
M0XL$`4N+-`$/R$B)\HG`2,'J($J)!$%(B?!(P>XX2,'H*"4`_P``2`GP2(G6
M2,'B"$C!YAB!X@``_P")]D@)\$@)T$J)1$$(28/`"$F#^$!UKDB-L0`"```/
M'X``````2(M!:$@S04!(@\$(2#-!"$@S0?A(C10`2,'H'T@)T(/@_TB)07A(
M.?%UU4R+%TB+7Q!(BW<@2(MO&$R+3PA,B=!,B=)(P>H;2,'@!4@)T`,$)(V4
M,)EY@EI(B=A(BW0D"$@QZ$PAR$@QZ$B-M#69>8):1(TL`DR)RDR)R$C!Z`)(
MP>(>2`G"2(G838GHB=%)P>@;2#'(3"'02#'82`'P3(GN2,'F!4P)QD2-)`9,
MB=9,B=!(P>8>2,'H`D@)\$B+="0038GC2#'"2<'K&T&)P$PAZDB-M#.9>8):
M2#'*2`'R3(GF2,'F!4P)WD2-'!9,B>Y(BU0D&$G![0)(P>8>3`GN2#'P2(V4
M$9EY@EI,B=E,(>!!B?9,,<!(P>D;2`'03(G:2,'B!4@)RDR)X4G![`)$C2P"
M2,'A'DB+5"0@3`GA2(GP2#'(3(GN08G,3"'828V4$)EY@EI(P>X;3#'P2`'0
M3(GJ2,'B!4@)\D2-!`),B=I(BT0D*$G!ZP)(P>(>3`G:3(G&2#'128V$!IEY
M@EI(P>X;3"'I08G33#'A2`'!3(G`2,'@!4@)\$2--`A,B>A(BTPD,$G![0)(
MP>`>3`GH3(GV2#'"28V,#)EY@EI!B<5,(<),,=I(`<I,B?%(P>$%2,'N&T@)
M\4R)QDG!Z`)$C2012,'F'DB+5"0X3`G&2#'P3(GA08GP3"'P28V4$YEY@EI(
MP>D;3#'H2`'03(GB2,'B!4@)RDR)\4G![@)$C1P"2,'A'DB+5"1`3`GQ2(GP
M2#'(3(G>08G.3"'@28V4%9EY@EI(P>X;3#'`2`'03(G:2,'B!4@)\D2-+`),
MB>)(BT0D2$G![`)(P>(>3`GB3(GN2#'128V$`)EY@EI(P>X;3"'908G43#'Q
M2`'!3(GH2,'@!4@)\$2-!`A,B=A(BTPD4$G!ZP)(P>`>3`G83(G&2#'"28V,
M#IEY@EI(P>X;3"'J08G#3#'B2`'*3(G!2,'A!4@)\4R)[DG![0)$C3012,'F
M'DB+5"183`GN2#'P3(GQ08GU3"'`28V4%)EY@EI(P>D;3#'82`'03(GR2,'B
M!4@)RDR)P4G!Z`)$C20"2,'A'DB+5"1@3`G!2(GP2#'(3(GF08G(28V4$YEY
M@EI,(?!(P>X;3#'H2`'03(GB2,'B!4@)\D2-'`),B?)(BT0D:$C!XAY)P>X"
M3`GR3(G>2#'128V$!9EY@EI(P>X;3"'A08G63#'!2`'!3(G82,'@!4@)\$2-
M+`A,B>!(BTPD<$G![`)(P>`>3`G@3(GN2#'"28V,")EY@EI(P>X;3"':08G$
M3#'R2`'*3(GI2,'A!4@)\4R)WDG!ZP)$C0012,'F'DB+5"1X3`G>2#'P3(G!
M08GS3"'H28V4%IEY@EI(P>D;3#'@2`'03(G"2,'B!4@)RDR)Z4G![0)$C30"
M2,'A'DB+E"2`````3`GI2(GP2#'(3(GV08G-3"'`28V4%)EY@EI(P>X;3#'8
M2`'03(GR2,'B!4@)\D2-)`),B<)(BX0DB````$G!Z`)(P>(>3`G"3(GF2#'1
M28V$`YEY@EI(P>X;3"'Q08G03#'I2`'!3(G@2,'@!4@)\$B+M"20````1(T<
M"$R)\$G![@)(P>`>3`GP28VT-9EY@EI-B=U(,<))P>T;B<%,(>),,<)(`?),
MB=Y(P>8%3`GNB?9(`?),B>9)P>P"2,'F'D&)U4P)YDR+I"28````2#'P3"'8
M3XV$()EY@EI(,<A-B>Q)P>P;3`'`38GH2<'@!4T)X$6)P$P!P$V)V$G!ZP))
MP>`>08G$30G828GSB?9-,<-(`[0DJ````$0QVDR+G"2@````2HV,&:'KV6Y-
MB>-)P>L;2`'13(GB2,'B!4P)VHG22`'13(GJ2<'M`DC!XAY!B<M,">I-B<5%
MB<!),=5,`X0DL````$0QZ$V)W4B-M`:AZ]EN3(G82<'M&TC!X`5,">B)P$@!
M\$R)YDG![`)(P>8>08G%3`GF28G4B=)),?1$,>%-B>Q(`Y0DN````$V-A`BA
MZ]EN3(GI2<'L&TC!X05,">&)R4D!R$R)V4G!ZP)(P>$>18G$3`G928GSB?9)
M,<M(`[0DP````$0QV$V)XTB-E`*AZ]EN3(G@2<'K&TC!X`5,"=B)P$@!PDR)
MZ$G![0)(P>`>08G33`GH28G-B<E),<5(`XPDR````$4QZ$V)W4Z-A`:AZ]EN
M3(G>2<'M&TC!Y@5,">Z)]DP!QDV)X$G![`))P>`>08GU30G@28G$B<!-,<1$
M,>)-B>Q(C8P1H>O9;DR)ZDC!X@5)P>P;2`.$)-````!,">*)TD@!T4R)VDG!
MZP)(P>(>08G,3`G:38G#18G`23'33`.$)-@```!$,=Y-B>-(C;0PH>O9;DR)
MX$G!ZQM(P>`%3`G8B<!(`?!,B>Y)P>T"2,'F'D&)PTP)[DF)U8G223'U2`.4
M).````!$,>E-B=U-C80(H>O9;DR)V4G![1M(P>$%3`GIB<E)`<A,B>%)P>P"
M2,'A'D6)Q4P)X4F)](GV23',1#'@38GL2(V4`J'KV6Y,B>A)P>P;2,'@!4P)
MX(G`2`'"3(G82`.T).@```!)P>L"2,'@'D&)U$P)V$F)RXG)23'#2`.,)/``
M``!%,=A-B>-.C80&H>O9;DR)YDG!ZQM(P>8%3`G>B?9,`<9-B>A)P>T"2<'@
M'D&)\TT)Z$F)Q8G`33'%2`.$)/@```!$,>I-B=U(C8P1H>O9;DR)VDG![1M(
MP>(%3`GJB=)(`=%,B>))P>P"2,'B'D&)S4P)XDV)Q$6)P$DQU$0QYDV)[$B-
MM#"AZ]EN3(GH2<'L&TC!X`5,">")P$@!\$R)WDC!YAY)P>L"3`.$)``!``!,
M"=Y)B=-!B<1),?.)TD@#E"0(`0``1#'938GC38V$"*'KV6Y,B>%)P>L;2,'A
M!4P)V8G)20'(3(GI2<'M`DC!X1Y%B<-,">E)B?6)]DDQS4@#M"00`0``1#'H
M38G=2(V4`J'KV6Y,B=A)P>T;2,'@!4P)Z(G`2`'"3(G@2<'L`DC!X!Y!B=5,
M">!)B<R)R4DQQ$4QX$V)[$Z-A`:AZ]EN3(GN2<'L&TC!Y@5,">:)]DP!QDV)
MV$G!ZP))P>`>08GT30G82`.,)!@!``!)B<--,<.)P$@#A"0@`0``1#':38GC
M2<'K&TB-C!&AZ]EN3(GB2,'B!4P)VHG22`'13(GJ2<'M`DC!XAY!B<M,">I-
MB<5%B<!),=5,`X0D*`$``$0Q[DV)W4B-M#"AZ]EN3(G82<'M&TC!X`5,">B)
MP$@!\$R)YDG![`)(P>8>08G%3`GF28G4B=)),?1(`Y0D,`$``$0QX4V)[$V-
MA`BAZ]EN3(GI2<'L&TC!X05,">&)R4D!R$R)V4G!ZP)(P>$>18G$3`G928GS
MB?9),<M$,=A-B>-(`[0D.`$``$B-E`*AZ]EN3(G@2<'K&TC!X`5,"=A$C1P0
M3(GH2<'M`DC!X!Y,">A)B<V)R4DQQ8G"13'H38G=3HV$!J'KV6Y,B=Y)P>T;
M2,'F!4P)[DR+K"1``0``1HTT!DV)X$G![`))P>`>30G@3`G`1(G&28G$2(G0
M2"'P32'<20G$N-R\&X])`<5,`>E-B?5)`<Q,B?%)P>T;2,'A!4P)Z4F)]4$!
MS$R)V4G!ZP)(P>$>3`G908G+20G(32'P32'=30GH3(NL)$@!``!)`<5,`>I-
MB>5)`=!,B>))P>T;2,'B!4P)ZD:-+`),B?))P>X"2,'B'DP)\DV)WD&)T$@)
MT4TAQDPAX4P)\4R+M"10`0``20'&3`'V38GN2`'Q3(GN2<'N&TC!Y@5,"?9$
MC30.3(GF2<'L`DC!YAY,">9-B<2)\4@)\DDAS$PAZDP)XDR+I"18`0``20'$
M30'C38GT3`':38GS2<'C!4G![!M-">-%C20338GK2<'M`DG!XQY-">M)B<U$
MB=I,"=Y)(=5,(?9,">Y,BZPD8`$``$D!Q4T!Z$V)Y4P!QDV)X$G![1M)P>`%
M30GH18TL,$V)\$G![@))P>`>30GP28G61(G&30G#22'V32'C30GS3(NT)&@!
M``!)`<9,`?%-B>Y)`<M,B>E)P>X;2,'A!4P)\4:--!E,B>%)P>P"2,'A'DP)
MX4F)]$&)RTD)R$TAZ$TAW$T)X$R+I"1P`0``20'$3`'B38GT20'03(GR2<'L
M&TC!X@5,">)&C20"3(GJ2<'M`DC!XAY,">I-B=U!B=!("=%-(<5,(?%,">E,
MBZPD>`$``$D!Q4P![DV)Y4@!\4R)YDG![1M(P>8%3`GN1(TL#DR)]DG![@)(
MP>8>3`GV38G&B?%("?))(<Y,(>),"?),B[0D@`$``$D!QDT!\TV)[DP!VDV)
MZTG!XP5)P>X;30GS18TT$TV)XTG![`))P>,>30GC28G,1(G:3`G>22'43"'N
M3`GF3(ND)(@!``!)`<1-`>!-B?1,`<9-B?!)P>P;2<'@!4T)X$6-)#!-B>A)
MP>T"2<'@'DT)Z$F)U42)QDT)PTDA]4TA\TT)ZTR+K"20`0``20'%3`'I38GE
M20'+3(GA2<'M&TC!X05,">E&C2P93(GQ2<'N`DC!X1Y,"?%)B?9)"<A!B<M-
M(=Y-(>!-"?!,B[0DF`$``$D!QDP!\DV)[DD!T$R)ZDG![AM(P>(%3`GR1HTT
M`DR)XDG![`)(P>(>3`GB38G<08G02`G132'$3"'I3`GA3(ND)*`!``!)`<1,
M`>9-B?1(`?%,B?9)P>P;2,'F!4P)YD2-)`Y,B>Y)P>T"2,'F'DP)[DV)Q8GQ
M2`GR22'-3"'R3`GJ3(NL)*@!``!)`<5-`>M-B>5,`=I-B>-)P>T;2<'C!4T)
MZT6-+!--B?-)P>X"2<'C'DT)\TF)SD2)VDP)WDDAUDPAYDP)]DR+M"2P`0``
M20'&30'P38GN3`'&38GH2<'N&TG!X`5-"?!%C30P38G@2<'L`DG!X!Y-">!)
MB=1$B<9-"<-)(?1-(>M-">-,BZ0DN`$``$D!Q$P!X4V)]$D!RTR)\4G![!M(
MP>$%3`GA1HTD&4R)Z4G![0)(P>$>3`GI28GU08G+20G(32'P32'=30GH3(NL
M),`!``!)`<5,`>I-B>5)`=!,B>))P>T;2,'B!4P)ZD:-+`),B?))P>X"2,'B
M'DV)V$P)\D&)UD@)T4TA\$PAX4P)P4R+A"3(`0``20'`3`'&38GH2`'Q3(GN
M2<'H&TC!Y@5,"<9$C00.3(GF2<'L`DC!YAY,B?%,">9!B?1("?),(>%,(>I(
M"<I(BXPDT`$``$@!P4D!RTR)P4@#A"38`0``3`':38G#2,'A!4G!ZQM,"=F)
MR4P!\$@!RDR)Z4G![0)(P>$>08G33`GI38GE08G/2`G.32']3"'&3`GN38G=
M2`'P3(G>2<'M&TC!Y@5,">Z)]D@!\$R)QDG!Z`)(P>8>08G%20GPOM;!8LI,
M,<$QRDB+C"3@`0``2`'Q20',3(GI3`'B38GL2,'A!4G![!M,">&)R4@!RDR)
MV4C!X1Y)P>L"08G420G+3(G!38GF3#'92<'N&T6)P#'(2(N,).@!``!(`?%)
M`<]*C0PX3(G@2,'@!4P)\(G`3(TT`4R)Z$G![0)(P>`>3(G918G;20G%2(N$
M)/`!``!%B?=,,>DQRDR)^4@!\$C!Z1M,`<!(`<),B?A(P>`%2`G(2(N,)/@!
M``")P$@!PDR)X$G![`)(P>`>2`'Q08G03`G@3`'938GK23'#38G$18GM13'>
M2<'L&TZ-'#%,B<%(P>$%3`GAB<E)`<M,B?E)P>\"2,'A'D6)W$D)STB+C"0`
M`@``2`'Q3`'I28G%B<!-,?U$,>I,C2P13(GB3(GA2,'I&TC!X@5("<I,B<%)
MP>@"B=)(P>$>20'52(N4)`@"``!,"<%-B?A%B>Y%B?]),<A(`?)%,<-(`=!,
MB?).C0083(GP2,'J&TC!X`5("=!(B<J)R8G`20'`3(G@2<'L`DC!X!Y%B<-)
M"<1(BX0D$`(``$PQXD$QU4R)VD@!\$P!^$D!Q4R)V$C!X`5(P>H;2`G03(GR
M2<'N`HG`2,'B'DD!Q4B+A"08`@``3`GR18GO2`'P2`'(3(GA18GD2#'103'(
M3(GY20'`3(GX2,'I&TC!X`5("<B)P$D!P$R)V$G!ZP)(P>`>18G&20G#2(N$
M)"`"``!,B?%(P>D;2`'P3`'@28G4B=)-,=Q%,>5.C20H3(GP2,'@!4@)R$B+
MC"0H`@``B<!)`<1,B?A)P>\"2`'Q2,'@'D6)Y4P)^$@!RDR)V4@QP46)VT$Q
MR$R)Z4D!T$R)ZDC!Z1M(P>(%2`G*B=))`=!,B?))P>X"2,'B'D6)QTD)UDB+
ME"0P`@``3(GY2,'I&T@!\DP!VDF)PXG`33'S13'<3HT<(DR)^DC!X@5("<I,
MB>E)P>T"B=)(P>$>20'32(N4)#@"``!,">E%B=Q(`?)(`=!,B?)%B?9(,<I!
M,=!,B>))`<!,B>!(P>H;2,'@!4@)T$B)RHG)B<!)`<!,B?A)P>\"2,'@'D6)
MQ4D)QTB+A"1``@``2`'P3#'Z3`'P03'33(GJ20'#3(GH2,'J&TC!X`5("=!,
MB>))P>P"B<!(P>(>20'#2(N$)$@"``!,">)%B=Y)B=1(`?!(`<A,B?E%B?](
M,=&)TD$QR$J-#`!,B?!-B?!)P>@;2,'@!4P)P(G`2`'!3(GH2<'M`DC!X!Y!
MB<A)"<5(BX0D4`(``$TQ[$4QXTV)Q$@!\$G![!M,`?A)`<-,B<!(P>`%3`G@
MB<!)`<-,B?!(P>`>2<'N`D6)W$P)\$R+M"18`@``20'V20'63(GJ18GM2#'"
M,=%)C10.3(GA38GF2<'N&TC!X05,"?&)R4@!RDR)P4G!Z`)(P>$>08G620G(
M2(N,)&`"``!(`?%,`>E)B<6)P$TQQ44QZTV)]4D!RTR)\4G![1M(P>$%3`GI
MB<E)`<M,B>%)P>P"2,'A'D6)W4D)S$B+C"1H`@``2`'Q2`'(3(G!18G`3#'A
M,<I(C0P03(GH3(GJ2,'J&TC!X`5("=!,B?))P>X"2,'B'HG`20G62(N4)'`"
M``!(`<&)R$@!\DP!PDV)X$TQ\$4QPTF)P$P!VDF)PTG!X`5)P>L;30G828G#
M2,'H`DG!XQY!`=!,B>I)"<-(BX0D>`(``$C!XAY)P>T"00';20G51(GB3(E?
M$$@!\$0![4@!PDR)\$B);QA,,>@QP4B-!`I,B<),B<%(P>(%2,'I&T4!R$@)
MRDR)1P@!T$$!PD0#=R!(BX0DB`(``&1(,P0E*````$R)%TR)=R!U$DB!Q)@"
M``!;74%<05U!7D%?P^CBX___9I!!5T%6055!5%532(/L"$B%_P^$L0```$R+
M/8IX(`!-A?\/A*$````/M@>$P'0$/#UU7D4QY$F+'TB%VW0Y28GU28G^36/D
M3(G]#Q^``````$R)XDR)]DB)W^C"XO__A<!U!T*`/",]=$=(@\4(2(M=`$B%
MVW7:2(/$"$B)V%M=05Q!74%>05_##Q^$``````!)B?Q)@\0!00^V!"2$P'0$
M/#UU[T$I_.N,#Q^``````$PI_4J-7",!2,']`T&);0#KM&8/'T0``#';ZZH/
M'T``55-(B?U(@^P89$B+!"4H````2(E$)`@QP$B-7"0$9I`QP$B)WDB)[^@#
M____2(7`=#9(8U0D!$B+!9IW(`!(C0302(M0"$B%TDB)$'329I!(@\`(2(M0
M"$B%TDB)$'7PZ[YF#Q]$``!(BT0D"&1(,P0E*````'4'2(/$&%M=P^B,XO__
M9I!F+@\?A```````05=!5D%505154TB)\TB)_4B#["AD2(L$)2@```!(B40D
M&#'`,<"`/CT/E,!(`<-(B=_H.>+__TB-="0428G$2(GO,<#H5_[__TB%P`^$
M#@$``$B)QTF)Q>@3XO__3#G@#X/B````3&-T)!1)P>8##[9%`(3`#X2M`0``
M/#T/A*4!``!(B>CK#0\?A```````@/H]=`M(@\`!#[80A-)U\$@IZ$B83`,U
MG'8@`$J-?"`"Z/KB__](A<!)B08/A'L!``!(8U0D%$B+!7IV(`!(C4T!2(L4
MT`^V10`\/8@"=":$P'40ZR!F+@\?A```````/#UT$DB#P0$/MD'_2(/"`83`
MB`)UZL8"/3'`#Q]$```/M@P#B$P"`4B#P`&$R77P,<!(BW0D&&1(,S0E*```
M``^%$0$``$B#Q"A;74%<05U!7D%?PP\?`$B#PP$/MD/_28/%`83`08A%_W7L
MZ\)FD$R+/>%U(`!)@S\`#X2_````3(GX,=+K"P\?A```````1(GJ2(/`"$2-
M:@%(@S@`=>^-<@-(8_9(P>8#BP7?A2``A<!U6TB)]\<%SH4@``$```#H^>'_
M_TB%P`^$?0```$UCQ4R)_DB)QTZ--,4`````3(E$)`A,B?+H@N+__TR+1"0(
M2(G!2(D%6W4@`$K'1,$(`````$2);"04Z6_^__],B?_H..+__TB%P$B)P4B)
M!3-U(`!T)DUCQ4Z--,4`````Z\D/'T``,<#I=O[__Y"^$````$4Q[>E>____
MN/_____IV_[__^@TX/__#Q]``$%7059!54%455-(@>RX````9$B+!"4H````
M2(F$)*@````QP$B%_W0(@#\`28G^=2](BX0DJ````&1(,P0E*`````^%)`$`
M`$B!Q+@```!;74%<05U!7D%?PV8/'T0``.AKW___2(7`2(G#=,1(C40D$$B-
M+=P;``!,C274&P``3(T]T!L``$B)!"1(B=_HC>'__TB%P`^$M````$R-2!.Y
M`@```$B)[TR)SO.F=-RY`P```$R)SDR)Y_.F=,U,B?=,B4PD".A5W___3(M,
M)`A)B<5,B<_H1=___T&-?`4"2&/_Z'C@__],BTPD"$F)Q4B)QTV)\$R)^4C'
MPO____^^`0```#'`Z-3A__](BQ0DOP$```!,B>[HH][__X/X_TR)[W00BT0D
M*"4`\```/0!```!T,.@FWO__3(GOZ/[=___I1/___V8/'X0``````$B)W^A8
MW___3(GWZ+#>___IS/[__^B6_O__Z\[HO][__P\?1```9BX/'X0``````%-(
MB?N+/49S(`#HP=___TB-D``"``!(B=Z_`0```.C=X/__A<!T"3'`6\,/'T0`
M`(L]&G,@`.B5W___BX`8`@``)0#P```]`$```'0=BSW]<B``Z'C?__^+@!@"
M```E`/```#T`H```=;U(B=^^`@```.A)X/__A<`/E,`/ML!;PP\?1```9BX/
M'X0``````$%6055)B?9!5%5)B?Q32(T].!H``+K_#P``2('L$!```$B)XTB)
MWF1(BP0E*````$B)A"0($```,<#H0=W__X7`#XZ)````C5#_1(LM;W(@`$AC
MZH`\+`!T5DACZ$B)ZKXO````2(G?Z&/>__](A<!T1D2)[^C&WO__2(GI2(G:
M3(GF2(G'Z,7?__](BX0D"!```&1(,P0E*````'4[2('$$!```%M=05Q!74%>
MPV:0A=)UJ0\?0`!$B>_H@-[__TR)\DR)YDB)Q^B2W?__Z[M$BRWI<2``Z]_H
M0MW__V:02(/L"(L]UG$@`.A1WO__2(L5:G$@`$B-#4L;``!(C358&0``2(G'
M2(/$".EPWO__2(/L"(L]IG$@`.@AWO__2(G'Z+G___^+/9-Q(`#H#M[__TR-
M!;@:``!(C140%```2(TU,1D``$4QR4B)QTB#Q`A,B<'I=][__P\?@`````!5
M4TB!["@@``!D2(L$)2@```!(B80D&"```#'`2(GC2(VL)!`0``#H%-S__TR-
M#<48``!(C0WS&```08G`N@$0``"^`0```$B)WS'`Z!_?__^Z`!```$B)[DB)
MW^B_V___A<!X4XUX`4B)PTAC_^A]W?__2(7`2(G!=!A(8]M(B>Y(B<=(B=KH
M--W__TB)P<8$&`!(BY0D&"```&1(,Q0E*````$B)R'432('$*"```%M=PP\?
M1```,<GKU^C_V___#Q]$``!F+@\?A```````Z2O___^09BX/'X0``````$%7
M059!54%428GT55-(B?M(C3U"&```2('L*!```&1(BP0E*````$B)A"08$```
M,<!(C70D#.C%]___OB\```!(B=](B<7HM=O__TB%P'1`2(T]"Q@``$B)WC'`
MZ/_X__](B=A(BXPD&!```&1(,PPE*`````^%F@$``$B!Q"@0``!;74%<05U!
M7D%?PP\?`$B)W^@XV___2(TUT!<``$R)YT&)Q>A6W?__2(7`28G'=)Y!@\4!
M08`_`$R-9"003(TUJQ<```^$X@````\?0`!(A>UT$TR)_DB)[^C0V___A<`/
MA*(```!,B?_HX-K__XG"2)A!@'P'_R]U%P\?0`"#Z@%(8\)!@'P'_R]!Q@0'
M`'3M1`'J@?K_#P``#X\N____2(/L"$B-#3H8``!-B?%338GXN@`0``"^`0``
M`$R)YS'`Z$C=__^+/3)O(`#HK=O__TB-D``"``!,B>:_`0```.@)VO__A<!:
M674=BST-;R``Z(C;__^+@!@"```E`/```#T`@```=%Y(C37>%@``,?_H:-S_
M_TB%P$F)QP^$K/[__T&`/P`/A2+___](A>UT'4B-/4L6``"Y`@```$B)[O.F
M=,1F+@\?A```````3(T]+A8``+H!````Z3+___\/'X``````O@$```!,B>?H
M^]O__X7`=9%(C3UB%@``3(GFZ%CW__],B>?H8-S__^E/_O__Z,;9__]F#Q]$
M```/MA=(B?B$TG0>9@\?1```2(/'`8#Z+P^V%T@/1,>$TG7N\\,/'T``\\-F
M#Q]$``!(A?\/A,\```!54TB#[`@/MB]`A.UT*4B)^^AAV?__2(U4`_](.=-R
M$.L[#Q]$``!(@^H!2#G3=#>`.B]T\NL=2(/$"$B-/6H5``!;7>G.V___9@\?
M1```@#HO=#A(@^H!2#G3<O)(.=-U*@\?1```0(#]+W3*2(/$"$B-/:`5``!;
M7>F8V___#Q^$``````"`.B]U"4B#Z@%(.=-R\D@IVDB-0@)(/0`0``!W.TB-
M/=QM(`!(@\(!N0`0``!(B=[H6]K__TB-!<1M(`!(@\0(6UW##Q]$``!(C3W6
M%```Z3S;__\/'T``,<#KX`\?0`!32(T]*Q4``$B#[$!D2(L$)2@```!(B40D
M.#'`#[<%G18``$B-7"0,\P]O!7`6```/*40D$&:)1"0P,<#S#V\%;!8```\I
M1"0@Z$+U__](C3WG%```,<#H-/7__TB-/>$4```QP.@F]?__2(T]W!0``#'`
MZ!CU__](C3W5%```,<#H"O7__TB-/=<4```QP.C\]/__2(T]?A0``#'`Z.[T
M__](C3W'%```,<#HX/3__TB-/<,4```QP.C2]/__2(T]OQ0``#'`Z,3T__](
MC3U/%```,<#HMO3__TB-/:T4```QP$B)WNC5\___2(7`=!%(C3V#%```2(G&
M,<#H'_7__TB-/9<4```QP$B)WNBN\___2(7`=!%(C3V3%```2(G&,<#H^/3_
M_TB-/8T4```QP$B)WNB'\___2(7`=$)(C3W4$P``2(G&,<#HT?3__TB--9(4
M``!(C3WW$P``,<#HO/3__TB+1"0X9$@S!"4H````=6)(@\1`6\-F#Q]$``!(
MC3U%%```,<!(B=[H+_/__TB%P'4J2(UT)"%(C3T[%```N0H```#SIG6D2(UT
M)"M(C3VY$P``,<#H8O3__^N/2(T]J1,``$B)QC'`Z$_T___I>?___^C%UO__
M#Q]$``!(@^P89$B+!"4H````2(E$)`@QP(L%-FL@`(/X_W092(M\)`AD2#,\
M)2@```!U0$B#Q!C##Q]``$B-="0$2(T]3!,``#'`Z)7R__](B<(QP$B%TG02
M#[82@/HP#Y7!,<"$T@^5P"'(B07C:B``Z[#H3-;__V:09BX/'X0``````$B#
M[`CH1];__XG'Z/#5__](A<!T"TB+`$B#Q`C##Q\`,<#K]&:09BX/'X0`````
M`$%454B)_5-(C3U,$P``2(/L$&1(BP0E*````$B)1"0(,<!(C70D!.@$\O__
M2(7`2(GN='R`.`!(B<-T=$B)Q^ALV/__2(7`=75(B>_HK]7__TB)WTF)Q.BD
MU?__28U\!`+HVM;__TB#[`A,C0TN$@``2(T-'Q,``%-(Q\+_____2(G'28G$
M28GHO@$````QP.@KV/__2(T]OA(``$R)YC'`Z.KR__]86NL49@\?1```2(T]
MHQ(``#'`Z-+R__](BT0D"&1(,P0E*````'4)2(/$$%M=05S#Z#35__\/'T``
M05=!5D%5051)B?U54TB-/941``!(@>R(@0``9$B+!"4H````2(F$)'B!```Q
MP$B-!6$2``!,C60D+$C'1"1``````$C'A"28`````````$C'1"1@`````$B)
M1"0P2(T%\1```$R)YDB)1"0X2(T%SA$``$B)1"1P2(T%NQ$``$B)1"1X2(T%
M$!(``$B)A"2`````2(T%O1$``$B)A"2(````2(T%^A$``$B)A"20````2(T%
MTA$``$B)1"102(T%XQ$``$B)1"18,<#H@/#__TB%P'0)@#@`#X52`@``,<#H
M"_[__TB%P$B)PP^$CP(``$B)W^@GU/__2(U\``'H7=7__X`[`$F)QG0W3(T]
MGA$``$R)]0\?`$0/M@-(B>\QP$R)^4C'PO____^^`0```$B#PP%(@\4"Z*/6
M__^`.P!UUDB-7"1P2(T]\Q```.L02(/#"$B+.TB%_P^$>`$``#'`3(GFZ.;O
M__](A<!(B<5TWH`X`'392(G'Z`'U__^%P'3-2(GOZ#76__](A<!)B<</A$$!
M``!F#Q^$``````!,B?J+"DB#P@2-@?_^_O[WT2'()8"`@(!TZ8G!P>D0J8"`
M```/1,%(C4H"2`]$T8G!`,%,B?%(@]H#3"GZBS%(@\$$C8;__O[^]]8A\"6`
M@("`=.F)QL'N$*F`@```#T3&2(UQ`D@/1,Z)QD``QDB#V0-,*?&-G`H$!```
M2&/;2(G?Z#G4__](B<5(C06-$```059,C0V'#P``2(T-=!```$V)^%!(Q\+_
M____O@$```!(B>\QP.B%U?__OL`!``!(B>_H&-+__X/X_T%805EU$NC:T?__
M1(L(08/Y$0^%TP@``(L]1V<@`.C"T___2(V0``(``$B)[K\!````Z-[4__^%
MP$&)QP^$0P$``$F+30!(BSU89R``2(T5Z1```$F)Z+X!````,<`QV^C@U/__
MZWYF#Q]$```Q[68/'T0``$ACQ4B+7,0P2(7;=#N`.P!T-DB)WX/%`>B#\___
MA<!TWTB)W^BWU/__2(7`28G'#X6+_O__2&/%2(M<Q#!(A=MURV8/'T0``$4Q
M_^EP_O__2(G'2(D$).CD^___2(L$)$B)Q^AXU/__2(G##Q]$``!(BXPD>($`
M`&1(,PPE*````$B)V`^%Y0@``$B!Q(B!``!;74%<05U!7D%?PP\?0`!(C3T#
M#P``,>U(A?]T)F:0,<!,B>:#Q0'HL^W__TB%P'0%@#@`=2E(8\5(BWS$4$B%
M_W7<OPT```!(C1W/#@``Z)O2__])B<;I/OW__P\?`$B)Q^CHT___2(7`2(G#
M#X4-_?__Z\%F+@\?A```````BSW:92``Z%72__^+@!@"```E`/```#T`0```
M#X6<_O__BSVY92``Z#32__]$B[`<`@``Z!C1__]!.<8/A7S^__^+/9EE(`#H
M%-+__XN`&`(``"7_`0``/<`!```/A5O^__](B=_H!M+__TB-/20.``!(B<-,
MB>8QP.CB[/__2(7`#X1I`0``2(G'Z$'3__])BWT`2(G&Z,7T__](A<!)B<0/
MA$D!``!,B>?H@=#__X/X`WX\2&/02(T]%0X``+D%````28UT%/SSIG4D@_@$
M#X0+!@``@^@$2)A!@'P$_R\/A/H%``!F+@\?A```````,<#HB?G__X7`=14Q
M]DR)Y^@+TO__A<!!B<8/A?````!(C35Q#0``2(T]\@P``$R-)>P-```QP$R-
M+:,,``#HC>W__^B(S___051,C0V0#```4$B-#:,-``!(Q\+_____28GHO@$`
M``!(B=\QP.B.TO__6%KK368N#Q^$``````#HZ\[__X,X$75+Z$'/__]!@\<!
M2(/L"$B-#6P-``!!5$%738GI4$F)Z$C'PO____^^`0```$B)WS'`Z$'2__](
M@\0@OL`!``!(B=_HT,[__X/X_W2K2(GOZ(/.__](C3WE"P``2(G>,<#HXNS_
M_TB)W^A*^?__Z77]__\/'T0``$V+90#IKO[__P\?@`````"Z`@```$C'QN[_
M__^)Q^B=T?__2(V$)'`!``"Z!@```$2)]TB)QDB)!"3HT<___X"\)'`!````
M=0Z`O"1Q`0``0P^$B04``#'2,?9$B??H7='__[B)J\WO3(VL)*````!(QX0D
MH`````$C16=(B80DJ````$@MB\X25TC'A"2X````=E0R$$B)A"2P````2`7R
M!!@K2,>$),@`````````2(F$),````!)C44X2,>$)-``````````QX0D&`$`
M``````!(B40D"`\?A```````2(LT)+H`@```1(GWZ!_/__^%P$F)Q$&)P`^.
M<0$``$B+O"3(````26/$2(N4)-````"--,=(.?Y(B;0DR````$B#T@!(P>@=
M2`'02(F$)-````!(8X0D&`$``(7`#X0=`0``2(M,)`A!N$````!(BS0D02G`
M13G$10].Q$B-/`%)8]!)B==(B50D$.C@SO__BX0D&`$``$0!^(/X0(F$)!@!
M```/A5;___]%B>!,B>]%*?A,BWPD$$P#/"1$B40D'.BZT___1(M$)!P/'T0`
M`$&#^#]^>4&-0,")1"0<P>@&08G$B40D$$F#Q`%)P>0&30'\#Q]$``#S00]O
M!TR)[TF#QT`/$80DV````/-!#V]'T`\1A"3H````\T$/;T?@#Q&$)/@```#S
M00]O1_`/$80D"`$``.A%T___33G\=;B+1"001(M$)!S!X`9!*<!(BWPD"$EC
MT+E(````3(G^1(E$)!#H]\W__T2+1"001(F$)!@!``#IA?[__P\?1```3(L\
M).E'____#Q^``````$2)]^A(S?__3(ND),@```!,B[0DT````$R)X$C!Z`.#
MX#^-4`%(F,:$!-@```"`@_HX#X^#`@``N#@````Q]BG02&/2@_@(28U4%3@/
M@]P"``"H!`^%A@,``(7`=`NH`L8"``^%B@,``$R)\$R)[T2(M"03`0``2,'H
M&$2(I"07`0``3(VL)$`!``"(A"00`0``3(GP2,'H$(B$)!$!``!,B?!,C36V
M"0``2,'H"(B$)!(!``!,B>!(P>@8B(0D%`$``$R)X$C!Z!"(A"05`0``3(G@
M13'D2,'H"(B$)!8!``#H"=+__TB+A"2@````2(G"B(0D(P$``$C!ZAA$#[;"
MB)0D(`$``$B)PDC!ZA"(E"0A`0``2(G"2(N$)*@```!(P>H(B)0D(@$``$B)
MPHB$)"<!``!(P>H8B)0D)`$``$B)PDC!ZA"(E"0E`0``2(G"2(N$)+````!(
MP>H(B)0D)@$``$B)PHB$)"L!``!(P>H8B)0D*`$``$B)PDC!ZA"(E"0I`0``
M2(G"2(N$)+@```!(P>H(B)0D*@$``$B)PHB$)"\!``!(P>H8B)0D+`$``$B)
MPDC!ZA"(E"0M`0``2(G"2(N$),````!(P>H(B)0D+@$``$B)PHB$)#,!``!(
MP>H8B)0D,`$``$B)PDC!ZA"(E"0Q`0``2(G"2,'J"(B4)#(!``#I#`````\?
M`$8/MH0D(`$``$N-?&4`,<!,B?%(Q\+_____O@$```!)@\0!Z%C-__])@_P4
M==)(C05L"```QH0D:`$```!0055(C0TF"```3(T-$P<``+X!````28GH2,?"
M_____TB)WS'`Z!G-__]97NGG^O__9I!-BVT(387M#X0#^O__3(GOZ#O*__](
M@_@##X;Q^?__28UT!?Q(C3W-!P``N04```#SIDT/1.7IU?G__[A`````2&/*
M*=!)C4P-.'0/,=*)UH/"`3G"Q@0Q`'+S3(GOZ`W0__]F#^_`#Q&$)-@```!)
MQT5H`````$$/$45(00\115CI8_W__TF+30!(BSVO7B``2(T5``@``$F)Z+X!
M````,<`QV^@WS/__Z=+W__^)P4C'`@````!(QT0*^`````!(C4H(2(/A^$@I
MR@'0@^#X@_@(#X(0_?__@^#X,=*)UX/""#G"2(DT.7+SZ?G\__^`O"1R`0``
M00^%:?K__X"\)',!``!##X5;^O__@+PD=`$``$@/A4WZ__^`O"1U`0``10^%
M/_K__[H"````2,?&QO___T2)]^B4R___3(L\)+HI````1(GW3(G^Z-#)__](
MC07:!@``4$%7Z7'^__^0QP(`````QT0"_`````#I=OS__S'_9HE\`O[I:OS_
M_^C<R/__9I!F+@\?A```````05=!5D%505154TB#[!B+/5Q=(`!D2(L$)2@`
M``!(B40D"#'`3(UL)`3HPLG__XL]/%T@`$B)P^BTR?__#[:3N````$B-/3H%
M``!,B>Z(D+D````QP.B6Y/__2(7`=`F`.#$/A`@#```QP.C![___BSW[7"``
MZ';)__](C34:!@``N0L```"Z`0```$B)Q^@=R?__2(7`#X3$````@ST];2``
M`4B+0!!$BS7"7"``3(M@*`^.KP```#'MNP$```#K.@\?@`````!)BW<02(L%
M!6T@`$ACTTB+/-#HP<C__X7`BQ7Y;"``#X4(`@``@\,!@\4!.=,/C?H!``!$
MB??H[<C__S')2&/53(GF2(G'Z+W)__](A<`/A,P!``!,BSA$BS5*7"``08M'
M#"4`!"``/0`$``!TDD2)]^BRR/__3(G^N0(````QTDB)Q^C0Q___1(LU&5P@
M`$B)QNEM____D$2+-0E<(`!$B??H@<C__TB--2H%``"Y`P```+H!````2(G'
MZ"C(__](A<!(B<-T-4B+0!"+/=9;(`!(BRCH3LC__TB-%?D$``!(B<=(B>[H
M7,?__TB+0Q!(BQCV0PY`#X7K`0``BSVE6R``Z"#(__](C370!```N0,```"Z
M`0```$B)Q^C'Q___2(7`2(G#=#U(C3U:`P``,<!,B>[H[N+__TB%P$B)Q0^$
M<@$``$B+0Q"+/5A;(`!(BQCHT,?__TB)ZDB)QTB)WNCBQO__BST\6R``Z+?'
M__](C35I!```N@$```!(B<?HP\?__XL]'5L@`$B)P^B5Q___2(T57`0``$B)
MWDB)Q^BCQO__BSW]6B``Z'C'__](C3W*`@``QH"Y`````$R)[C'`Z&#B__](
MA<!(B<-(B05+:R``#X2=````OL`!``!(B=_H<,7__XU0`8/Z`78)@_@1#X4/
M`0``2(M$)`AD2#,$)2@````/A?8```!(@\086UU!7$%=05Y!7\,/'T``BQ7R
M:B``1(LU>UH@`(U"_SGH#X5G_O__@_H!#XY>_O__NP$```!FD$2)]X/#`>C5
MQO__3(GF2(G'Z!K%__\Y';1J(`!$BS4]6B``?]OI+?[__V8/'T0``$B+/9%J
M(`#H5/#__TB%P$B)PTB)!8]J(``/A43___](C3TZ!```,<#HL\;__P\?`(!X
M`0`/A/7\___IZ?S__Y!(BP51:B``BSWC62``2(LH2(M#$$B+&.A4QO__2(GN
M2(G?Z`GG___I@O[__P\?0`"+/;I9(`#H-<;__TB)WDB)Q^B*QO__Z?K]___H
M`,7__XG!2(L%_VD@`$B-/>@#``!(B=I(BS`QP.@SQO__#Q\`55-(B?U(@^P(
MZ$+K__\/MA!(B<.$TG0:#Q^$``````!(@\`!@/HO#[802`]$V(32=>XQP.CG
M[?__2(7M=!V%P'09@'T``'032(T]'P(``+D$````2(G>\Z9T!TB#Q`A;7<-(
M@\0(2(GO6UWI0.3__TB+#?%8(`#I],3__P\?0`!!5T%628G7055!5$R-)2Y4
M(`!52(TM+E0@`%-!B?U)B?9,*>5(@^P(2,']`^@/P___2(7M="`QVP\?A```
M````3(GZ3(GV1(GO0?\4W$B#PP%(.=UUZDB#Q`A;74%<05U!7D%?PY!F+@\?
MA```````\\,``$B#[`A(@\0(PP````$``@`N+@`E<R\E<P`O<')O8R]S96QF
M+V5X90!$>6YA3&]A9&5R.CIB;V]T7T1Y;F%,;V%D97(`26YT97)N86QS.CI0
M05(Z.D)/3U0`+W!R;V,O)6DO)7,`4$%27U1%35``4$%27U!23T=.04U%`#H`
M+P!015),-4Q)0@!015),3$E"`%!%4DPU3U!4`%!%4DQ)3P!005)?24Y)5$E!
M3$E:140`4$%27U-005=.140`4$%27T-,14%.`%!!4E]$14)51P!005)?0T%#
M2$4`4$%27T=,3T)!3%]$14)51P!005)?1TQ/0D%,7U1-4$1)4@!005)?5$U0
M1$E2`%!!4E]'3$]"04Q?5$5-4`!005)?1TQ/0D%,7T-,14%.`%!!4E]#3$5!
M3CT`,0!,1%],24)205)97U!!5$@`55-%4@!365-414T`+W1M<`!414U01$E2
M`%1-4`!54T523D%-10`E,#)X`"5S)7,E<R5S`'!A<BT`<&%R;``N<&%R`"5S
M)7-C86-H92TE<R5S`"5S)7-T96UP+25U)7,`)7,E<W1E;7`M)74M)74E<P!!
M4D=6`!@`<&5R;``P`%!!4CHZ4&%C:V5R.CI615)324].`#$N,#0S`"UE`"TM
M`````````%]?14Y67U!!4E]#3$5!3E]?("`@("`@("`@("`@("`@````````
M``!P97)L>'-I+F,`````````)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@<W5B
M9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@```````"5S.B!P<FEV
M871E('-U8F1I<F5C=&]R>2`E<R!I<R!U;G-A9F4@*'!L96%S92!R96UO=F4@
M:70@86YD(')E=')Y('EO=7(@;W!E<F%T:6]N*0H```````!5;F%B;&4@=&\@
M8W)E871E(&-A8VAE(&1I<F5C=&]R>0``````````)7,Z(&-R96%T:6]N(&]F
M('!R:79A=&4@8V%C:&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\]
M)6DI"@``````````979A;"`G97AE8R`O=7-R+V)I;B]P97)L("`M4R`D,"`D
M>S$K(B1`(GTG"FEF(#`[(",@;F]T(')U;FYI;F<@=6YD97(@<V]M92!S:&5L
M;`IP86-K86=E(%]?<&%R7W!L.PIM>2`H)'!A<E]T96UP+"`D<')O9VYA;64L
M($!T;7!F:6QE*3L*14Y$('L@:68@*"1%3E9[4$%27T-,14%.?2D@>PIR97%U
M:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ0F%S96YA;64["G)E<75I
M<F4@1FEL93HZ4W!E8SL*;7D@)'1O<&1I<B`]($9I;&4Z.D)A<V5N86UE.CID
M:7)N86UE*"1P87)?=&5M<"D["F]U=',H<7%[4F5M;W9I;F<@9FEL97,@:6X@
M(B1P87)?=&5M<")]*3L*1FEL93HZ1FEN9#HZ9FEN9&1E<'1H*'-U8B![("@@
M+60@*2`_(')M9&ER(#H@=6YL:6YK('TL("1P87)?=&5M<"D["G)M9&ER("1P
M87)?=&5M<#L*:68@*"UD("1P87)?=&5M<"`F)B`D7D\@;F4@)TU35VEN,S(G
M*2!["FUY("1T;7`@/2!N97<@1FEL93HZ5&5M<"@*5$5-4$Q!5$4@/3X@)W1M
M<%A86%A8)RP*1$E2(#T^($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1T;W!D
M:7(I+`I3549&25@@/3X@)RYC;60G+`I53DQ)3DL@/3X@,"P**3L*<')I;G0@
M)'1M<"`B(R$O8FEN+W-H"G@],3L@=VAI;&4@6R!<)'@@+6QT(#$P(%T[(&1O
M"G)M("UR9B`G)'!A<E]T96UP)PII9B!;(%PA("UD("<D<&%R7W1E;7`G(%T[
M('1H96X*8G)E86L*9FD*<VQE97`@,0IX/6!E>'!R(%PD>"`K(#%@"F1O;F4*
M<FT@)R(@+B`D=&UP+3YF:6QE;F%M92`N("(G"B(["F-H;6]D(#`W,#`L)'1M
M<"T^9FEL96YA;64["FUY("1C;60@/2`D=&UP+3YF:6QE;F%M92`N("<@/B]D
M978O;G5L;"`R/B8Q("8G.PIC;&]S92`D=&UP.PIS>7-T96TH)&-M9"D["F]U
M=',H<7$H4W!A=VYE9"!B86-K9W)O=6YD('!R;V-E<W,@=&\@<&5R9F]R;2!C
M;&5A;G5P.B`I"BX@)'1M<"T^9FEL96YA;64I.PI]"GT@?0I"14=)3B!["DEN
M=&5R;F%L<SHZ4$%2.CI"3T]4*"D@:68@9&5F:6YE9"`F26YT97)N86QS.CI0
M05(Z.D)/3U0["F5V86P@>PI?<&%R7VEN:71?96YV*"D["FUY("1Q=6EE="`]
M("$D14Y6>U!!4E]$14)51WT["FUY("5#;VYF:6<@/2`H"G!A=&A?<V5P("`@
M(#T^("@D7D\@/7X@+UY-4U=I;B\@/R`G.R<@.B`G.B<I+`I?97AE("`@("`@
M("`]/B`H)%Y/(#U^("]>*#\Z35-7:6Y\3U,R?&-Y9W=I;BDO(#\@)RYE>&4G
M(#H@)R<I+`I?9&5L:6T@("`@("`]/B`H)%Y/(#U^("]>35-7:6Y\3U,R+R`_
M("=<7"<@.B`G+R<I+`HI.PI?<V5T7W!R;V=N86UE*"D["E]S971?<&%R7W1E
M;7`H*3L*;7D@*"1S=&%R=%]P;W,L("1D871A7W!O<RD["GL*;&]C86P@)%-)
M1WM?7U=!4DY?7WT@/2!S=6(@>WT["F]P96X@7T9(+"`G/"<L("1P<F]G;F%M
M92!O<B!L87-T.PIB:6YM;V1E*%]&2"D["FUY("1B=68["FUY("1S:7IE(#T@
M+7,@)'!R;V=N86UE.PIM>2`D;V9F<V5T(#T@-3$R.PIM>2`D:61X(#T@+3$[
M"G=H:6QE("@Q*0I["B1O9F9S970@/2`D<VEZ92!I9B`D;V9F<V5T(#X@)'-I
M>F4["G-E96L@7T9(+"`M)&]F9G-E="P@,B!O<B!D:64@<7%;<V5E:R!F86EL
M960@;VX@(B1P<F]G;F%M92(Z("0A73L*;7D@)&YR96%D(#T@<F5A9"!?1D@L
M("1B=68L("1O9F9S970["F1I92!Q<5MR96%D(&9A:6QE9"!O;B`B)'!R;V=N
M86UE(CH@)"%=('5N;&5S<R`D;G)E860@/3T@)&]F9G-E=#L*)&ED>"`](')I
M;F1E>"@D8G5F+"`B7&Y005(N<&U<;B(I.PIL87-T(&EF("1I9'@@/CT@,"!\
M?"`D;V9F<V5T(#T]("1S:7IE('Q\("1O9F9S970@/B`Q,C@@*B`Q,#(T.PHD
M;V9F<V5T("H](#(["GT*;&%S="!U;FQE<W,@)&ED>"`^/2`P.PHD;V9F<V5T
M("T]("1I9'@@+2`T.PIS965K(%]&2"P@+21O9F9S970L(#(["G)E860@7T9(
M+"`D8G5F+"`T.PIS965K(%]&2"P@+21O9F9S970@+2!U;G!A8VLH(DXB+"`D
M8G5F*2P@,CL*<F5A9"!?1D@L("1B=68L(#0["B1D871A7W!O<R`]("AT96QL
M(%]&2"D@+2`T.PIM>2`E<F5Q=6ER95]L:7-T.PIW:&EL92`H)&)U9B!E<2`B
M1DE,12(I('L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U
M;G!A8VLH(DXB+"`D8G5F*3L*;7D@)&9U;&QN86UE(#T@)&)U9CL*;W5T<RAQ
M<2A5;G!A8VMI;F<@9FEL92`B)&9U;&QN86UE(BXN+BDI.PIM>2`D8W)C(#T@
M*"`D9G5L;&YA;64@/7X@<WQ>*%MA+69<9%U[.'TI+WQ\("D@/R`D,2`Z('5N
M9&5F.PIM>2`H)&)A<V5N86UE+"`D97AT*2`]("@D8G5F(#U^(&U\*#\Z+BHO
M*3\H+BHI*%PN+BHI?"D["G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@
M)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FEF("AD969I;F5D*"1E>'0I(&%N
M9"`D97AT("%^("]<+B@_.G!M?'!L?&EX?&%L*20O:2D@>PIM>2`D9FEL96YA
M;64@/2!?=&5M<&9I;&4H(B1C<F,D97AT(BP@)&)U9BP@,#<U-2D["B1005(Z
M.DAE879Y.CI&=6QL0V%C:&5[)&9U;&QN86UE?2`]("1F:6QE;F%M93L*)%!!
M4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9FEL96YA;65](#T@)&9U;&QN86UE.PI]
M"F5L<VEF("@@)&9U;&QN86UE(#U^(&U\7B\_<VAL:6(O?"!A;F0@9&5F:6YE
M9"`D14Y6>U!!4E]414U0?2`I('L*;7D@)&9I;&5N86UE(#T@7W1E;7!F:6QE
M*"(D8F%S96YA;64D97AT(BP@)&)U9BP@,#<U-2D["F]U=',H(E-(3$E".B`D
M9FEL96YA;65<;B(I.PI]"F5L<V4@>PHD<F5Q=6ER95]L:7-T>R1F=6QL;F%M
M97T@/0HD4$%2.CI(96%V>3HZ36]D=6QE0V%C:&5[)&9U;&QN86UE?2`]('L*
M8G5F(#T^("1B=68L"F-R8R`]/B`D8W)C+`IN86UE(#T^("1F=6QL;F%M92P*
M?3L*?0IR96%D(%]&2"P@)&)U9BP@-#L*?0IL;V-A;"!`24Y#(#T@*'-U8B![
M"FUY("@D<V5L9BP@)&UO9'5L92D@/2!`7SL*<F5T=7)N(&EF(')E9B`D;6]D
M=6QE(&]R("$D;6]D=6QE.PIM>2`D9FEL96YA;64@/2!D96QE=&4@)')E<75I
M<F5?;&ES='LD;6]D=6QE?2!\?"!D;R!["FUY("1K97D["F9O<F5A8V@@*&ME
M>7,@)7)E<75I<F5?;&ES="D@>PIN97AT('5N;&5S<R`O7%$D;6]D=6QE7$4D
M+SL*)&ME>2`]("1?.R!L87-T.PI]"F1E;&5T92`D<F5Q=6ER95]L:7-T>R1K
M97E](&EF(&1E9FEN960H)&ME>2D["GT@;W(@<F5T=7)N.PHD24Y#>R1M;V1U
M;&5](#T@(B]L;V%D97(O)&9I;&5N86UE+R1M;V1U;&4B.PII9B`H)$5.5GM0
M05)?0TQ%04Y](&%N9"!D969I;F5D*"9)3SHZ1FEL93HZ;F5W*2D@>PIM>2`D
M9F@@/2!)3SHZ1FEL92T^;F5W7W1M<&9I;&4@;W(@9&EE("0A.PIB:6YM;V1E
M*"1F:"D["G!R:6YT("1F:"`D9FEL96YA;64M/GMB=69].PIS965K*"1F:"P@
M,"P@,"D["G)E='5R;B`D9F@["GT*96QS92!["FUY("1F:6QE;F%M92`](%]T
M96UP9FEL92@B)&9I;&5N86UE+3Y[8W)C?2YP;2(L("1F:6QE;F%M92T^>V)U
M9GTI.PIO<&5N(&UY("1F:"P@)SPG+"`D9FEL96YA;64@;W(@9&EE(")C86XG
M="!R96%D("1F:6QE;F%M93H@)"$B.PIB:6YM;V1E*"1F:"D["G)E='5R;B`D
M9F@["GT*9&EE(")";V]T<W1R87!P:6YG(&9A:6QE9#H@8V%N;F]T(&9I;F0@
M)&UO9'5L92%<;B(["GTL($!)3D,I.PIR97%U:7)E(%A33&]A9&5R.PIR97%U
M:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@
M17AP;W)T97(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R
M*"D["G)E<75I<F4@24\Z.D9I;&4["G=H:6QE("AM>2`D9FEL96YA;64@/2`H
M<V]R="!K97ES("5R97%U:7)E7VQI<W0I6S!=*2!["G5N;&5S<R`H)$E.0WLD
M9FEL96YA;65](&]R("1F:6QE;F%M92`]?B`O0E-$4$%.+RD@>PII9B`H)&9I
M;&5N86UE(#U^("]<+G!M8S\D+VDI('L*<F5Q=6ER92`D9FEL96YA;64["GT*
M96QS92!["F1O("1F:6QE;F%M92!U;FQE<W,@)&9I;&5N86UE(#U^("]S:71E
M8W5S=&]M:7IE7"YP;"0O.PI]"GT*9&5L971E("1R97%U:7)E7VQI<W1[)&9I
M;&5N86UE?3L*?0IL87-T('5N;&5S<R`D8G5F(&5Q(")02UPP,#-<,#`T(CL*
M)'-T87)T7W!O<R`]("AT96QL(%]&2"D@+2`T.PI]"FUY($!P87)?87)G<SL*
M;7D@*"1O=70L("1B=6YD;&4L("1L;V=F:"P@)&-A8VAE7VYA;64I.PID96QE
M=&4@)$5.5GM005)?05!07U)%55-%?3L@(R!S86YI=&EZ92`H4D554T4@;6%Y
M(&)E(&$@<V5C=7)I='D@<')O8FQE;2D*)'%U:65T(#T@,"!U;FQE<W,@)$5.
M5GM005)?1$5"54=].PII9B`H(21S=&%R=%]P;W,@;W(@*"1!4D=66S!=(&5Q
M("<M+7!A<BUO<'1I;VYS)R`F)B!S:&EF="DI('L*;7D@)61I<W1?8VUD(#T@
M<7<H"G`@("!B;&EB7W1O7W!A<@II("`@:6YS=&%L;%]P87(*=2`@('5N:6YS
M=&%L;%]P87(*<R`@('-I9VY?<&%R"G8@("!V97)I9GE?<&%R"BD["FEF("A`
M05)'5B!A;F0@)$%21U9;,%T@97$@)RTM<F5U<V4G*2!["G-H:69T($!!4D=6
M.PHD14Y6>U!!4E]!4%!?4D554T5](#T@<VAI9G0@0$%21U8["GT*96QS92![
M(",@;F]R;6%L('!A<FP@8F5H879I;W5R"FUY($!A9&1?=&]?:6YC.PIW:&EL
M92`H0$%21U8I('L*)$%21U9;,%T@/7X@+UXM*%M!24U/0DQB<7!I=7-4=ETI
M*"XJ*2\@;W(@;&%S=#L*:68@*"0Q(&5Q("=))RD@>PIP=7-H($!A9&1?=&]?
M:6YC+"`D,CL*?0IE;'-I9B`H)#$@97$@)TTG*2!["F5V86P@(G5S92`D,B([
M"GT*96QS:68@*"0Q(&5Q("=!)RD@>PIU;G-H:69T($!P87)?87)G<RP@)#([
M"GT*96QS:68@*"0Q(&5Q("=/)RD@>PHD;W5T(#T@)#(["GT*96QS:68@*"0Q
M(&5Q("=B)RD@>PHD8G5N9&QE(#T@)W-I=&4G.PI]"F5L<VEF("@D,2!E<2`G
M0B<I('L*)&)U;F1L92`]("=A;&PG.PI]"F5L<VEF("@D,2!E<2`G<2<I('L*
M)'%U:65T(#T@,3L*?0IE;'-I9B`H)#$@97$@)TPG*2!["F]P96X@)&QO9V9H
M+"`B/CXB+"`D,B!O<B!D:64@(EA86#H@0V%N;F]T(&]P96X@;&]G.B`D(2([
M"GT*96QS:68@*"0Q(&5Q("=4)RD@>PHD8V%C:&5?;F%M92`]("0R.PI]"G-H
M:69T*$!!4D=6*3L*:68@*&UY("1C;60@/2`D9&ES=%]C;61[)#%]*2!["F1E
M;&5T92`D14Y6>R=005)?5$5-4"=].PII;FET7VEN8R@I.PIR97%U:7)E(%!!
M4CHZ1&ES=#L*)GLB4$%2.CI$:7-T.CHD8VUD(GTH*2!U;FQE<W,@0$%21U8[
M"B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"1?*2!F;W(@0$%21U8["F5X:70["GT*
M?0IU;G-H:69T($!)3D,L($!A9&1?=&]?:6YC.PI]"GT*:68@*"1O=70I('L*
M>PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*?0IM
M>2`D<&%R(#T@<VAI9G0H0$%21U8I.PIM>2`D>FEP.PII9B`H9&5F:6YE9"`D
M<&%R*2!["D%R8VAI=F4Z.EII<#HZ<V5T0VAU;FM3:7IE*#$R."HQ,#(T*3L*
M;W!E;B!M>2`D9F@L("<\)RP@)'!A<B!O<B!D:64@(D-A;FYO="!F:6YD("<D
M<&%R)SH@)"$B.PIB:6YM;V1E*"1F:"D["F)L97-S*"1F:"P@)TE/.CI&:6QE
M)RD["B1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL**"`D>FEP+3YR96%D1G)O
M;49I;&5(86YD;&4H)&9H+"`D<&%R*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+
M*"D@*0IO<B!D:64@(E)E860@)R1P87(G(&5R<F]R.B`D(2(["GT*;7D@)65N
M=B`](&1O('L*:68@*"1Z:7`@86YD(&UY("1M971A(#T@)'II<"T^8V]N=&5N
M=',H)TU%5$$N>6UL)RDI('L*)&UE=&$@/7X@<R\N*EYP87(Z)"\O;7,["B1M
M971A(#U^(',O7EQ3+BHO+VUS.PHD;65T82`]?B`O7B`@*%M>.ETK*3H@*"XK
M*20O;6<["GT*?3L*;&]C86P@)"\@/2!<-#L*:68@*&1E9FEN960@)'!A<BD@
M>PIO<&5N(%!!4BP@)SPG+"`D<&%R(&]R(&1I92`B)"$Z("1P87(B.PIB:6YM
M;V1E*%!!4BD["F1I92`B)'!A<B!I<R!N;W0@82!005(@9FEL92(@=6YL97-S
M(#Q005(^(&5Q(")02UPP,#-<,#`T(CL*?0I#<F5A=&50871H*"1O=70I(#L*
M;7D@)&9H(#T@24\Z.D9I;&4M/FYE=R@*)&]U="P*24\Z.D9I;&4Z.D]?0U)%
M050H*2!\($E/.CI&:6QE.CI/7U=23TY,62@I('P@24\Z.D9I;&4Z.D]?5%)5
M3D,H*2P*,#<W-RP**2!O<B!D:64@)"$["F)I;FUO9&4H)&9H*3L*)"\@/2`H
M9&5F:6YE9"`D9&%T85]P;W,I(#\@7"1D871A7W!O<R`Z('5N9&5F.PIS965K
M(%]&2"P@,"P@,#L*;7D@)&QO861E<B`]('-C86QA<B`\7T9(/CL*:68@*"$D
M14Y6>U!!4E]615)"051)37T@86YD("1L;V%D97(@/7X@+UXH/SHC(7Q<0')E
M;2DO*2!["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PI005(Z.D9I
M;'1E<CHZ4&]D4W1R:7`M/FYE=RT^87!P;'DH7"1L;V%D97(L("0P*0I]"F9O
M<F5A8V@@;7D@)&ME>2`H<V]R="!K97ES("5E;G8I('L*;7D@)'9A;"`]("1E
M;G9[)&ME>7T@;W(@;F5X=#L*)'9A;"`](&5V86P@)'9A;"!I9B`D=F%L(#U^
M("]>6R<B72\["FUY("1M86=I8R`](")?7T5.5E]005)?(B`N('5C*"1K97DI
M("X@(E]?(CL*;7D@)'-E="`](")005)?(B`N('5C*"1K97DI("X@(CTD=F%L
M(CL*)&QO861E<B`]?B!S>R1M86=I8R@@*RE]>PHD;6%G:6,@+B`D<V5T("X@
M*"<@)R!X("AL96YG=&@H)#$I("T@;&5N9W1H*"1S970I*2D*?65G.PI]"B1F
M:"T^<')I;G0H)&QO861E<BD["B0O(#T@=6YD968["FEF("@D8G5N9&QE*2![
M"G)E<75I<F4@4$%2.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO
M861E<B@I.PII;FET7VEN8R@I.PIR97%U:7)E7VUO9'5L97,H*3L*;7D@0&EN
M8R`](&=R97`@>R`A+T)31%!!3B\@?0IG<F5P('L**"1B=6YD;&4@;F4@)W-I
M=&4G*2!O<@HH)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>V%R8VAL:6)E>'!](&%N
M9`HD7R!N92`D0V]N9FEG.CI#;VYF:6=[<')I=FQI8F5X<'TI.PI]($!)3D,[
M"FUY("5F:6QE<SL*)&9I;&5S>R1??2LK(&9O<B!`1'EN84QO861E<CHZ9&Q?
M<VAA<F5D7V]B:F5C=',L('9A;'5E<R`E24Y#.PIM>2`D;&EB7V5X="`]("1#
M;VYF:6<Z.D-O;F9I9WML:6)?97AT?3L*;7D@)7=R:71T96X["F9O<F5A8V@@
M*'-O<G0@:V5Y<R`E9FEL97,I('L*;7D@*"1N86UE+"`D9FEL92D["F9O<F5A
M8V@@;7D@)&1I<B`H0&EN8RD@>PII9B`H)&YA;64@/2`D4$%2.CI(96%V>3HZ
M1G5L;$-A8VAE>R1??2D@>PHD9FEL92`]("1?.PIL87-T.PI]"F5L<VEF("@O
M7BA<421D:7)<15PO*"XJ6UY#8UTI*5Q:+VDI('L**"1F:6QE+"`D;F%M92D@
M/2`H)#$L("0R*3L*;&%S=#L*?0IE;'-I9B`H;2%>+VQO861E<B];7B]=*R\H
M+BI;7D-C72E<6B$I('L*:68@*&UY("1R968@/2`D4$%2.CI(96%V>3HZ36]D
M=6QE0V%C:&5[)#%]*2!["B@D9FEL92P@)&YA;64I(#T@*"1R968L("0Q*3L*
M;&%S=#L*?0IE;'-I9B`H+68@(B1D:7(O)#$B*2!["B@D9FEL92P@)&YA;64I
M(#T@*"(D9&ER+R0Q(BP@)#$I.PIL87-T.PI]"GT*?0IN97AT('5N;&5S<R!D
M969I;F5D("1N86UE(&%N9"!N;W0@)'=R:71T96Y[)&YA;65]*RL["FYE>'0@
M:68@(7)E9B@D9FEL92D@86YD("1F:6QE(#U^("]<+EQ1)&QI8E]E>'1<120O
M.PIO=71S*"!J;VEN("(B+`IQ<2A086-K:6YG("(I+"!R968@)&9I;&4@/R`D
M9FEL92T^>VYA;65](#H@)&9I;&4L"G%Q*"(N+BXI"BD["FUY("1C;VYT96YT
M.PII9B`H<F5F*"1F:6QE*2D@>PHD8V]N=&5N="`]("1F:6QE+3Y[8G5F?3L*
M?0IE;'-E('L*;W!E;B!&24Q%+"`G/"<L("1F:6QE(&]R(&1I92`B0V%N)W0@
M;W!E;B`D9FEL93H@)"$B.PIB:6YM;V1E*$9)3$4I.PHD8V]N=&5N="`](#Q&
M24Q%/CL*8VQO<V4@1DE,13L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YN97<M
M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4I"FEF("$D14Y6>U!!4E]615)"051)
M37T@86YD("1N86UE(#U^("]<+B@_.G!M?&EX?&%L*20O:3L*4$%2.CI&:6QT
M97(Z.E!A=&-H0V]N=&5N="T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE
M+"`D;F%M92D["GT*;W5T<RAQ<2A7<FET=&5N(&%S("(D;F%M92(I*3L*)&9H
M+3YP<FEN="@B1DE,12(I.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H
M)&YA;64I("L@.2DI.PHD9F@M/G!R:6YT*'-P<FEN=&8H"B(E,#AX+R5S(BP@
M07)C:&EV93HZ6FEP.CIC;VUP=71E0U)#,S(H)&-O;G1E;G0I+"`D;F%M90HI
M*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@;&5N9W1H*"1C;VYT96YT*2DI.PHD
M9F@M/G!R:6YT*"1C;VYT96YT*3L*?0I]"B1Z:7`M/G=R:71E5&]&:6QE2&%N
M9&QE*"1F:"D@:68@)'II<#L*)&-A8VAE7VYA;64@/2!S=6)S='(@)&-A8VAE
M7VYA;64L(#`L(#0P.PII9B`H(21C86-H95]N86UE(&%N9"!M>2`D;71I;64@
M/2`H<W1A="@D;W5T*2E;.5TI('L*;7D@)&-T>"`](&5V86P@>R!R97%U:7)E
M($1I9V5S=#HZ4TA!.R!$:6=E<W0Z.E-(02T^;F5W*#$I('T*?'P@979A;"![
M(')E<75I<F4@1&EG97-T.CI32$$Q.R!$:6=E<W0Z.E-(03$M/FYE=R!]"GQ\
M(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ340U.R!$:6=E<W0Z.DU$-2T^;F5W
M('T["FUY("1S:&%?=F5R<VEO;B`](&5V86P@>R`D1&EG97-T.CI32$$Z.E9%
M4E-)3TX@?2!\?"`P.PII9B`H)'-H85]V97)S:6]N(&5Q("<U+C,X)R!O<B`D
M<VAA7W9E<G-I;VX@97$@)S4N,SDG*2!["B1C='@M/F%D9&9I;&4H)&]U="P@
M(F(B*2!I9B`H)&-T>"D["GT*96QS92!["FEF("@D8W1X(&%N9"!O<&5N*&UY
M("1F:"P@(CPD;W5T(BDI('L*8FEN;6]D92@D9F@I.PHD8W1X+3YA9&1F:6QE
M*"1F:"D["F-L;W-E*"1F:"D["GT*?0HD8V%C:&5?;F%M92`]("1C='@@/R`D
M8W1X+3YH97AD:6=E<W0@.B`D;71I;64["GT*)&-A8VAE7VYA;64@+CT@(EPP
M(B!X("@T,2`M(&QE;F=T:"`D8V%C:&5?;F%M92D["B1C86-H95]N86UE("X]
M(")#04-(12(["B1F:"T^<')I;G0H)&-A8VAE7VYA;64I.PHD9F@M/G!R:6YT
M*'!A8VLH)TXG+"`D9F@M/G1E;&P@+2!L96YG=&@H)&QO861E<BDI*3L*)&9H
M+3YP<FEN="@B7&Y005(N<&U<;B(I.PHD9F@M/F-L;W-E.PIC:&UO9"`P-S4U
M+"`D;W5T.PIE>&ET.PI]"GL*;&%S="!U;FQE<W,@9&5F:6YE9"`D<W1A<G1?
M<&]S.PI?9FEX7W!R;V=N86UE*"D["G)E<75I<F4@4$%2.PI005(Z.DAE879Y
M.CI?:6YI=%]D>6YA;&]A9&5R*"D["GL*<F5Q=6ER92!&:6QE.CI&:6YD.PIR
M97%U:7)E($%R8VAI=F4Z.EII<#L*?0IM>2`D>FEP(#T@07)C:&EV93HZ6FEP
M+3YN97<["FUY("1F:"`]($E/.CI&:6QE+3YN97<["B1F:"T^9F1O<&5N*&9I
M;&5N;RA?1D@I+"`G<B<I(&]R(&1I92`B)"$Z("1`(CL*)'II<"T^<F5A9$9R
M;VU&:6QE2&%N9&QE*"1F:"P@)'!R;V=N86UE*2`]/2!!<F-H:79E.CI::7`Z
M.D%:7T]+*"D@;W(@9&EE("(D(3H@)$`B.PIP=7-H($!005(Z.DQI8D-A8VAE
M+"`D>FEP.PHD4$%2.CI,:6)#86-H97LD<')O9VYA;65](#T@)'II<#L*)'%U
M:65T(#T@(21%3E9[4$%27T1%0E5'?3L*;W5T<RAQ<2A<)$5.5GM005)?5$5-
M4'T@/2`B)$5.5GM005)?5$5-4'TB*2D["FEF("AD969I;F5D("1%3E9[4$%2
M7U1%35!]*2![(",@<VAO=6QD(&)E('-E="!A="!T:&ES('!O:6YT(0IF;W)E
M86-H(&UY("1M96UB97(@*"`D>FEP+3YM96UB97)S("D@>PIN97AT(&EF("1M
M96UB97(M/FES1&ER96-T;W)Y.PIM>2`D;65M8F5R7VYA;64@/2`D;65M8F5R
M+3YF:6QE3F%M93L*;F5X="!U;FQE<W,@)&UE;6)E<E]N86UE(#U^(&U["EX*
M+S]S:&QI8B\**#\Z)$-O;F9I9SHZ0V]N9FEG>W9E<G-I;VY]+RD_"B@_.B1#
M;VYF:6<Z.D-O;F9I9WMA<F-H;F%M97TO*3\**%M>+UTK*0HD"GUX.PIM>2`D
M97AT<F%C=%]N86UE(#T@)#$["FUY("1D97-T7VYA;64@/2!&:6QE.CI3<&5C
M+3YC871F:6QE*"1%3E9[4$%27U1%35!]+"`D97AT<F%C=%]N86UE*3L*:68@
M*"UF("1D97-T7VYA;64@)B8@+7,@7R`]/2`D;65M8F5R+3YU;F-O;7!R97-S
M9613:7IE*"DI('L*;W5T<RAQ<2A3:VEP<&EN9R`B)&UE;6)E<E]N86UE(B!S
M:6YC92!I="!A;')E861Y(&5X:7-T<R!A="`B)&1E<W1?;F%M92(I*3L*?2!E
M;'-E('L*;W5T<RAQ<2A%>'1R86-T:6YG("(D;65M8F5R7VYA;64B('1O("(D
M9&5S=%]N86UE(BDI.PHD;65M8F5R+3YE>'1R86-T5&]&:6QE3F%M960H)&1E
M<W1?;F%M92D["F-H;6]D*#`U-34L("1D97-T7VYA;64I(&EF("1>3R!E<2`B
M:'!U>"(["GT*?0I]"GT*=6YL97-S("@D4$%2.CI,:6)#86-H97LD<')O9VYA
M;65]*2!["F1I92`\/"`B+B(@=6YL97-S($!!4D=6.PI5<V%G93H@)#`@6R`M
M06QI8BYP87(@72!;("U)9&ER(%T@6R`M36UO9'5L92!=(%L@<W)C+G!A<B!=
M(%L@<')O9W)A;2YP;"!="B0P(%L@+4)\+6(@72!;+4]O=71F:6QE72!S<F,N
M<&%R"BX*)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE(#T@)#`@/2!S
M:&EF="A`05)'5BD["GT*<W5B($-R96%T95!A=&@@>PIM>2`H)&YA;64I(#T@
M0%\["G)E<75I<F4@1FEL93HZ0F%S96YA;64["FUY("@D8F%S96YA;64L("1P
M871H+"`D97AT*2`]($9I;&4Z.D)A<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L
M("@G7"XN*B<I*3L*<F5Q=6ER92!&:6QE.CI0871H.PI&:6QE.CI0871H.CIM
M:W!A=&@H)'!A=&@I('5N;&5S<R@M92`D<&%T:"D[(",@;6MP871H(&1I97,@
M=VET:"!E<G)O<@I]"G-U8B!R97%U:7)E7VUO9'5L97,@>PIR97%U:7)E(&QI
M8CL*<F5Q=6ER92!$>6YA3&]A9&5R.PIR97%U:7)E(&EN=&5G97(["G)E<75I
M<F4@<W1R:6-T.PIR97%U:7)E('=A<FYI;F=S.PIR97%U:7)E('9A<G,["G)E
M<75I<F4@0V%R<#L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%<G)N
M;SL*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["G)E<75I<F4@17AP;W)T97([
M"G)E<75I<F4@1F-N=&P["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&
M:6QE.CI3<&5C.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E($-O;F9I9SL*
M<F5Q=6ER92!)3SHZ2&%N9&QE.PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E
M($-O;7!R97-S.CI:;&EB.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER
M92!005(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!005(Z.D1I<W0[
M"G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PIR97%U:7)E(%!!4CHZ
M1FEL=&5R.CI0871C:$-O;G1E;G0["G)E<75I<F4@871T<FEB=71E<SL*979A
M;"![(')E<75I<F4@0W=D('T["F5V86P@>R!R97%U:7)E(%=I;C,R('T["F5V
M86P@>R!R97%U:7)E(%-C86QA<CHZ571I;"!].PIE=F%L('L@<F5Q=6ER92!!
M<F-H:79E.CI5;GII<#HZ0G5R<W0@?3L*979A;"![(')E<75I<F4@5&EE.CI(
M87-H.CI.86UE9$-A<'1U<F4@?3L*979A;"![(')E<75I<F4@4&5R;$E/.R!R
M97%U:7)E(%!E<FQ)3SHZ<V-A;&%R('T["F5V86P@>R!R97%U:7)E('5T9C@@
M?3L*?0IS=6(@7W-E=%]P87)?=&5M<"!["FEF("AD969I;F5D("1%3E9[4$%2
M7U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\I('L*)'!A<E]T
M96UP(#T@)#$["G)E='5R;CL*?0IF;W)E86-H(&UY("1P871H("@**&UA<"`D
M14Y6>R1??2P@<7<H(%!!4E]435!$25(@5$U01$E2(%1%35!$25(@5$5-4"!4
M35`@*2DL"G%W*"!#.EQ<5$5-4"`O=&UP("X@*0HI('L*;F5X="!U;FQE<W,@
M9&5F:6YE9"`D<&%T:"!A;F0@+60@)'!A=&@@86YD("UW("1P871H.PIM>2`D
M=7-E<FYA;64["FUY("1P=W5I9#L*979A;"![*"1P=W5I9"D@/2!G971P=W5I
M9"@D/BD@:68@9&5F:6YE9"`D/CM].PII9B`H(&1E9FEN960H)E=I;C,R.CI,
M;V=I;DYA;64I("D@>PHD=7-E<FYA;64@/2`F5VEN,S(Z.DQO9VEN3F%M93L*
M?0IE;'-I9B`H9&5F:6YE9"`D<'=U:60I('L*)'5S97)N86UE(#T@)'!W=6ED
M.PI]"F5L<V4@>PHD=7-E<FYA;64@/2`D14Y6>U5315).04U%?2!\?"`D14Y6
M>U5315)]('Q\("=365-414TG.PI]"B1U<V5R;F%M92`]?B!S+UQ7+U\O9SL*
M;7D@)'-T;7!D:7(@/2`B)'!A=&@D0V]N9FEG>U]D96QI;7UP87(M(BYU;G!A
M8VLH(D@J(BP@)'5S97)N86UE*3L*;6MD:7(@)'-T;7!D:7(L(#`W-34["FEF
M("@A)$5.5GM005)?0TQ%04Y](&%N9"!M>2`D;71I;64@/2`H<W1A="@D<')O
M9VYA;64I*5LY72D@>PIO<&5N("AM>2`D9F@L("(\(BX@)'!R;V=N86UE*3L*
M<V5E:R`D9F@L("TQ."P@,CL*<WES<F5A9"`D9F@L(&UY("1B=68L(#8["FEF
M("@D8G5F(&5Q(")<,$-!0TA%(BD@>PIS965K("1F:"P@+34X+"`R.PIS>7-R
M96%D("1F:"P@)&)U9BP@-#$["B1B=68@/7X@<R]<,"\O9SL*)'-T;7!D:7(@
M+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE+2(@+B`D8G5F.PI]"F5L<V4@>PIM
M>2`D8W1X(#T@979A;"![(')E<75I<F4@1&EG97-T.CI32$$[($1I9V5S=#HZ
M4TA!+3YN97<H,2D@?0I\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03$[
M($1I9V5S=#HZ4TA!,2T^;F5W('T*?'P@979A;"![(')E<75I<F4@1&EG97-T
M.CI-1#4[($1I9V5S=#HZ340U+3YN97<@?3L*;7D@)'-H85]V97)S:6]N(#T@
M979A;"![("1$:6=E<W0Z.E-(03HZ5D524TE/3B!]('Q\(#`["FEF("@D<VAA
M7W9E<G-I;VX@97$@)S4N,S@G(&]R("1S:&%?=F5R<VEO;B!E<2`G-2XS.2<I
M('L*)&-T>"T^861D9FEL92@D<')O9VYA;64L(")B(BD@:68@*"1C='@I.PI]
M"F5L<V4@>PII9B`H)&-T>"!A;F0@;W!E;BAM>2`D9F@L("(\)'!R;V=N86UE
M(BDI('L*8FEN;6]D92@D9F@I.PHD8W1X+3YA9&1F:6QE*"1F:"D["F-L;W-E
M*"1F:"D["GT*?0HD<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]8V%C:&4M
M(B`N("@@)&-T>"`_("1C='@M/FAE>&1I9V5S="`Z("1M=&EM92`I.PI]"F-L
M;W-E*"1F:"D["GT*96QS92!["B1%3E9[4$%27T-,14%.?2`](#$["B1S=&UP
M9&ER("X]("(D0V]N9FEG>U]D96QI;7UT96UP+20D(CL*?0HD14Y6>U!!4E]4
M14U0?2`]("1S=&UP9&ER.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*;&%S=#L*
M?0HD<&%R7W1E;7`@/2`D,2!I9B`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM0
M05)?5$5-4'T@/7X@+R@N*RDO.PI]"G-U8B!?=&5M<&9I;&4@>PIM>2`H)&YA
M;64L("1C;VYT96YT<RP@)&UO9&4I(#T@0%\["FUY("1F=6QL;F%M92`]("(D
M<&%R7W1E;7`O)&YA;64B.PIU;FQE<W,@*"UE("1F=6QL;F%M92D@>PIM>2`D
M=&5M<&YA;64@/2`B)&9U;&QN86UE+B0D(CL*;W!E;B!M>2`D9F@L("<^)RP@
M)'1E;7!N86UE(&]R(&1I92`B8V%N)W0@=W)I=&4@)'1E;7!N86UE.B`D(2([
M"F)I;FUO9&4@)&9H.PIP<FEN="`D9F@@)&-O;G1E;G1S.PIC;&]S92`D9F@[
M"F-H;6]D("1M;V1E+"`D=&5M<&YA;64@:68@9&5F:6YE9"`D;6]D93L*<F5N
M86UE*"1T96UP;F%M92P@)&9U;&QN86UE*2!O<B!U;FQI;FLH)'1E;7!N86UE
M*3L*?0IR971U<FX@)&9U;&QN86UE.PI]"G-U8B!?<V5T7W!R;V=N86UE('L*
M:68@*&1E9FEN960@)$5.5GM005)?4%)/1TY!345](&%N9"`D14Y6>U!!4E]0
M4D]'3D%-17T@/7X@+R@N*RDO*2!["B1P<F]G;F%M92`]("0Q.PI]"B1P<F]G
M;F%M92!\?#T@)#`["FEF("@D14Y6>U!!4E]414U0?2!A;F0@:6YD97@H)'!R
M;V=N86UE+"`D14Y6>U!!4E]414U0?2D@/CT@,"D@>PHD<')O9VYA;64@/2!S
M=6)S='(H)'!R;V=N86UE+"!R:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D
M96QI;7TI("L@,2D["GT*:68@*"$D14Y6>U!!4E]04D]'3D%-17T@;W(@:6YD
M97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI(#X](#`I('L*:68@*&]P
M96X@;7D@)&9H+"`G/"<L("1P<F]G;F%M92D@>PIR971U<FX@:68@+7,@)&9H
M.PI]"FEF("@M<R`B)'!R;V=N86UE)$-O;F9I9WM?97AE?2(I('L*)'!R;V=N
M86UE("X]("1#;VYF:6=[7V5X97T["G)E='5R;CL*?0I]"F9O<F5A8V@@;7D@
M)&1I<B`H<W!L:70@+UQ1)$-O;F9I9WMP871H7W-E<'U<12\L("1%3E9[4$%4
M2'TI('L*;F5X="!I9B!E>&ES=',@)$5.5GM005)?5$5-4'T@86YD("1D:7(@
M97$@)$5.5GM005)?5$5-4'T["B1D:7(@/7X@<R]<421#;VYF:6=[7V1E;&EM
M?5Q%)"\O.PHH*"1P<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R
M;V=N86UE)$-O;F9I9WM?97AE?2(I+"!L87-T*0II9B`M<R`B)&1I<B1#;VYF
M:6=[7V1E;&EM?21P<F]G;F%M921#;VYF:6=[7V5X97TB.PHH*"1P<F]G;F%M
M92`]("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(BDL(&QA<W0I"FEF
M("US("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*?0I]"G-U8B!?
M9FEX7W!R;V=N86UE('L*)#`@/2`D<')O9VYA;64@?'P]("1%3E9[4$%27U!2
M3T=.04U%?3L*:68@*&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]
M*2`\(#`I('L*)'!R;V=N86UE(#T@(BXD0V]N9FEG>U]D96QI;7TD<')O9VYA
M;64B.PI]"FUY("1P=V0@/2`H9&5F:6YE9"`F0W=D.CIG971C=V0I(#\@0W=D
M.CIG971C=V0H*0HZ("@H9&5F:6YE9"`F5VEN,S(Z.D=E=$-W9"D@/R!7:6XS
M,CHZ1V5T0W=D*"D@.B!@<'=D8"D["F-H;VUP*"1P=V0I.PHD<')O9VYA;64@
M/7X@<R]>*#\]7"Y<+C]<421#;VYF:6=[7V1E;&EM?5Q%*2\D<'=D)$-O;F9I
M9WM?9&5L:6U]+SL*)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE.PI]
M"G-U8B!?<&%R7VEN:71?96YV('L*:68@*"`D14Y6>U!!4E])3DE424%,25I%
M1'TK*R`]/2`Q("D@>PIR971U<FX["GT@96QS92!["B1%3E9[4$%27TE.251)
M04Q)6D5$?2`](#(["GT*9F]R("AQ=R@@4U!!5TY%1"!414U0($-,14%.($1%
M0E5'($-!0TA%(%!23T=.04U%($%21T,@05)'5E\P("D@*2!["F1E;&5T92`D
M14Y6>R=005)?)RXD7WT["GT*9F]R("AQ=R\@5$U01$E2(%1%35`@0TQ%04X@
M1$5"54<@+RD@>PHD14Y6>R=005)?)RXD7WT@/2`D14Y6>R=005)?1TQ/0D%,
M7R<N)%]](&EF(&5X:7-T<R`D14Y6>R=005)?1TQ/0D%,7R<N)%]].PI]"FUY
M("1P87)?8VQE86X@/2`B7U]%3E9?4$%27T-,14%.7U\@("`@("`@("`@("`@
M("`B.PII9B`H)$5.5GM005)?5$5-4'TI('L*9&5L971E("1%3E9[4$%27T-,
M14%.?3L*?0IE;'-I9B`H(65X:7-T<R`D14Y6>U!!4E]'3$]"04Q?0TQ%04Y]
M*2!["FUY("1V86QU92`]('-U8G-T<B@D<&%R7V-L96%N+"`Q,B`K(&QE;F=T
M:"@B0TQ%04XB*2D["B1%3E9[4$%27T-,14%.?2`]("0Q(&EF("1V86QU92`]
M?B`O7E!!4E]#3$5!3CTH7%,K*2\["GT*?0IS=6(@;W5T<R!["G)E='5R;B!I
M9B`D<75I970["FEF("@D;&]G9F@I('L*<')I;G0@)&QO9V9H(")`7UQN(CL*
M?0IE;'-E('L*<')I;G0@(D!?7&XB.PI]"GT*<W5B(&EN:71?:6YC('L*<F5Q
M=6ER92!#;VYF:6<["G!U<V@@0$E.0RP@9W)E<"!D969I;F5D+"!M87`@)$-O
M;F9I9SHZ0V]N9FEG>R1??2P@<7<H"F%R8VAL:6)E>'`@<')I=FQI8F5X<"!S
M:71E87)C:&5X<"!S:71E;&EB97AP"G9E;F1O<F%R8VAE>'`@=F5N9&]R;&EB
M97AP"BD["GT*<&%C:V%G92!M86EN.PIR97%U:7)E(%!!4CL*=6YS:&EF="!`
M24Y#+"!<)E!!4CHZ9FEN9%]P87(["E!!4BT^:6UP;W)T*$!P87)?87)G<RD[
M"F1I92!Q<2AP87(N<&PZ($-A;B=T(&]P96X@<&5R;"!S8W)I<'0@(B1P<F]G
M;F%M92(Z($YO('-U8V@@9FEL92!O<B!D:7)E8W1O<GE<;BD*=6YL97-S("UE
M("1P<F]G;F%M93L*9&\@)'!R;V=N86UE.PI#3U)%.CIE>&ET*"0Q*2!I9B`H
M)$`@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)$`@:68@)$`["GT[
M"B0Z.E]?15)23U(@/2`D0"!I9B`D0#L*?0I#3U)%.CIE>&ET*"0Q*2!I9B`H
M)#HZ7U]%4E)/4B`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D.CI?
M7T524D]2(&EF("0Z.E]?15)23U(["C$["E]?14Y$7U\*```````!&P,[[```
M`!P```"(@___.`$``$B'__]@`0``6(?__T0&``"(B?__"`$``)B*__]X`0``
MJ*#__\@!``!XH?__%`(```BB__]``@``6*3__XP"``#8I?__V`(``&BF___X
M`@``2*?__SP#``!XI___5`,``,BG__]L`P``F*C__Y@#``"HJ/__K`,``,BJ
M__\,!```^*K__R`$``#HJ___<`0``,BM__^4!```2*[__[`$``!XKO__S`0`
M`%BO__\,!0``N+O__\0%``"HO___$`8``!C`__]P!@``*,#__X@&``"8P/__
MT`8````````4``````````%Z4@`!>!`!&PP'")`!!Q`4````'````'B(__\K
M```````````````4``````````%Z4@`!>!`!&PP'")`!```D````'````$B"
M___``P````X01@X82@\+=PB``#\:.RHS)"(`````%````$0```#@A?__"```
M````````````3````%P````8B?__#A8```!"#A"/`D(.&(X#1@X@C01"#BB,
M!40.,(8&00XX@P='#M`%`^85"@XX00XP00XH0@X@0@X80@X00@X(00L```!(
M````K````-B>___,`````$(.$(\"0@X8C@-"#B"-!$(.*(P%00XPA@9!#CB#
M!T0.0`)L"@XX1`XP00XH0@X@0@X80@X00@X(20L`*````/@```!<G___A```
M``!!#A"&`D$.&(,#1PXP`G,*#AA!#A!!#@A!"P!(````)`$``,"?__],`@``
M`$(.$(\"0@X8C@-"#B"-!$(.*(P%00XPA@9!#CB#!TH.8`,F`0H..$$.,$$.
M*$(.($(.&$(.$$(."$0+2````'`!``#$H?__<0$```!"#A"/`D(.&(X#0@X@
MC01"#BB,!4$.,(8&00XX@P='#O`!?@H..$$.,$$.*$(.($(.&$(.$$(."$<+
M`!P```"\`0``^*+__X$`````00X0@P)I"@X(1@L"4`X(0````-P!``!HH___
MW@````!"#A".`D(.&(T#10X@C`1!#BB&!40.,(,&4P[`(`*$"@XP00XH00X@
M0@X80@X00@X(0PL4````(`(```2D__\P`````$0.$&<."``4````.`(``!RD
M__])`````$0.$'T."``H````4`(``%2D___!`````$$.$(8"00X8@P-'#L!`
M`J<*#AA!#A!!#@A&"Q````!\`@``^*3__P4`````````7````)`"``#TI/__
M&@(```!"#A"/`D(.&(X#0@X@C01"#BB,!40.,(8&00XX@P=1#N`@`F0*#CA!
M#C!!#BA"#B!"#AA"#A!"#@A$"P*6#N@@2P[P('D.Z"!!#N`@````$````/`"
M``"TIO__*@````````!,````!`,``-"F___L`````$H.$(8"00X8@P-$#B!U
M"@X82,,.$$'&#@A+"V(*#AA(PPX00<8."$T+`D`.&$$.$$$."$;#QE`.((,#
MA@(``"````!4`P``<*?__]L!````00X0@P)+#E`#;`$*#A!!#@A'"Q@```!X
M`P``+*G__W0`````1`X@;PH."$4+```8````E`,``)"I__\D`````$0.$%@*
M#@A$"P``/````+`#``"DJ?__W`````!"#A",`D$.&(8#1`X@@P1+#C`"6`XX
M3PY`;@XX00XP:@H.($$.&$$.$$(."$$+`+0```#P`P``1*K__U0,````0@X0
MCP)"#AB.`T(.((T$0@XHC`5$#C"&!D$..(,'3@[`@P(#&`(.R(,"4@[0@P)H
M#LB#`D(.P(,"`P(!"@XX00XP00XH0@X@0@X80@X00@X(10L#J@$.R(,"2`[0
M@P)A#LB#`D$.P(,"8P[(@P))#M"#`D(.V(,"1`[@@P)=#L"#`@/[!`[(@P)"
M#M"#`F@.R(,"00[`@P(#7P$*#LB#`D(.T(,"1@M(````J`0``.RU___M`P``
M`$(.$(\"0@X8C@-"#B"-!$(.*(P%00XPA@9!#CB#!T0.4`/+`@H..$$.,$$.
M*$(.($(.&$(.$$(."$4+,````/0$``"0N?__<`````!!#A"&`D$.&(,#1PX@
M`E8*#AA!#A!!#@A!"T0.&$0.$$$.""@````H!0``#('__RT"````00X0A@)!
M#AB#`T0.4`.]`0H.&$$.$$$."$$+%````%0%``"@N?__#```````````````
M1````&P%``"8N?__90````!"#A"/`D(.&(X#10X@C01"#BB,!4@.,(8&2`XX
M@P=-#D!R#CA!#C!!#BA"#B!"#AA"#A!"#@@`$````+0%``#`N?__`@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````@"$`
M``````!`(0````````````````````````````````````````$`````````
M`0`````````!`````````,L!`````````0````````#6`0````````$`````
M````X`$````````!`````````"\"`````````0````````![`P````````P`
M````````8!H````````-`````````)17````````&0````````!@JR``````
M`!L`````````"``````````:`````````&BK(```````'``````````(````
M`````/7^_V\`````F`(````````%``````````@-````````!@````````"0
M`P````````H`````````[`0````````+`````````!@`````````%0``````
M``````````````,`````````R*T@```````"`````````(@%````````%```
M```````'`````````!<`````````V!0````````'`````````$`3````````
M"`````````"8`0````````D`````````&``````````>``````````@`````
M````^___;P`````!```(`````/[__V\`````P!(```````#___]O``````(`
M````````\/__;P````#T$0```````/G__V\`````!```````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````(BK(```````````````````
M`````````)8:````````IAH```````"V&@```````,8:````````UAH`````
M``#F&@```````/8:````````!AL````````6&P```````"8;````````-AL`
M``````!&&P```````%8;````````9AL```````!V&P```````(8;````````
MEAL```````"F&P```````+8;````````QAL```````#6&P```````.8;````
M````]AL````````&'````````!8<````````)AP````````V'````````$8<
M````````5AP```````!F'````````'8<````````AAP```````"6'```````
M`*8<````````MAP```````#&'````````-8<````````YAP```````#V'```
M``````8=````````%AT````````F'0```````#8=````````1AT```````!6
M'0```````&8=````````=AT```````"&'0```````)8=````````IAT`````
M``"V'0```````,8=````````UAT```````#F'0```````/8=````````!AX`
M```````6'@```````"8>````````-AX`````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````BP(```````_____P````#`6@```````$=#
M0SH@*$1E8FEA;B`W+C,N,"TQ-BD@-RXS+C``1T-#.B`H1&5B:6%N(#<N,RXP
M+3$S*2`W+C,N,```+G-H<W1R=&%B`"YI;G1E<G``+FYO=&4N04))+71A9P`N
M;F]T92YG;G4N8G5I;&0M:60`+F=N=2YH87-H`"YD>6YS>6T`+F1Y;G-T<@`N
M9VYU+G9E<G-I;VX`+F=N=2YV97)S:6]N7W(`+G)E;&$N9'EN`"YR96QA+G!L
M=``N:6YI=``N<&QT+F=O=``N=&5X=``N9FEN:0`N<F]D871A`"YE:%]F<F%M
M95]H9'(`+F5H7V9R86UE`"YI;FET7V%R<F%Y`"YF:6YI7V%R<F%Y`"YD871A
M+G)E;"YR;P`N9'EN86UI8P`N9&%T80`N8G-S`"YC;VUM96YT````````````
M````````````````````````````````````````````````````````````
M```````````````````+`````0````(`````````.`(````````X`@``````
M`!P````````````````````!````````````````````$P````<````"````
M`````%0"````````5`(````````@````````````````````!```````````
M`````````"$````'`````@````````!T`@```````'0"````````)```````
M``````````````0````````````````````T````]O__;P(`````````F`(`
M``````"8`@```````/@`````````!0`````````(````````````````````
M/@````L````"`````````)`#````````D`,```````!X"0````````8````!
M````"``````````8`````````$8````#`````@`````````(#0````````@-
M````````[`0```````````````````$```````````````````!.````____
M;P(`````````]!$```````#T$0```````,H`````````!0`````````"````
M``````(`````````6P```/[__V\"`````````,`2````````P!(```````"`
M``````````8````"````"````````````````````&H````$`````@``````
M``!`$P```````$`3````````F`$````````%``````````@`````````&```
M``````!T````!````$(`````````V!0```````#8%````````(@%````````
M!0```!<````(`````````!@`````````?@````$````&`````````&`:````
M````8!H````````7````````````````````!````````````````````'D`
M```!````!@````````"`&@```````(`:````````P`,`````````````````
M`!``````````$`````````"$`````0````8`````````0!X```````!`'@``
M``````@````````````````````(``````````@`````````C0````$````&
M`````````%`>````````4!X```````!".0``````````````````$```````
M`````````````),````!````!@````````"45P```````)17````````"0``
M``````````````````0```````````````````"9`````0````(`````````
MH%<```````"@5P```````%@_```````````````````(````````````````
M````H0````$````"`````````/B6````````^)8```````#L````````````
M````````!````````````````````*\````!`````@````````#HEP``````
M`.B7````````^`4```````````````````@```````````````````"Y````
M#@````,`````````8*L@``````!@JP````````@````````````````````(
M``````````@`````````Q0````\````#`````````&BK(```````:*L`````
M```(````````````````````"``````````(`````````-$````!`````P``
M``````!PJR```````'"K````````$P```````````````````!``````````
M``````````#>````!@````,`````````B*L@``````"(JP```````$`"````
M````!@`````````(`````````!``````````B`````$````#`````````,BM
M(```````R*T````````P`@``````````````````"``````````(````````
M`.<````!`````P``````````L"````````"P````````(```````````````
M``````@```````````````````#M````"`````,`````````(+`@```````@
ML````````(@0```````````````````@````````````````````\@````$`
M```P````````````````````(+`````````Z`````````````````````0``
M```````!``````````$````#`````````````````````````%JP````````
@^P````````````````````$`````````````````````
